@@ -14,14 +14,14 @@ sub compiler {
   }
 }
 
-sub class_paths {
+sub include_dirs {
   my $self = shift;
   if (@_) {
-    $self->{class_paths} = $_[0];
+    $self->{include_dirs} = $_[0];
     return $self;
   }
   else {
-    return $self->{class_paths};
+    return $self->{include_dirs};
   }
 }
 
@@ -47,9 +47,9 @@ sub new {
 }
 
 sub use {
-  my ($self, $class_name, $file, $line) = @_;
+  my ($self, $basic_type_name, $file, $line) = @_;
   
-  my $success = $self->compile($class_name, __FILE__, __LINE__);
+  my $success = $self->compile($basic_type_name, __FILE__, __LINE__);
   unless ($success) {
     $self->print_error_messages(*STDERR);
     exit(255);
