@@ -38,14 +38,14 @@ sub builder {
   }
 }
 
-sub class_paths {
+sub include_dirs {
   my $self = shift;
   if (@_) {
-    $self->builder->class_paths($_[0]);
+    $self->builder->include_dirs($_[0]);
     return $self;
   }
   else {
-    return $self->builder->class_paths;
+    return $self->builder->include_dirs;
   }
 }
 
@@ -133,15 +133,15 @@ sub new {
   my $self = {@_};
   
   # Target class name
-  my $class_name = $self->{class_name};
-  unless (defined $class_name) {
+  my $basic_type_name = $self->{class_name};
+  unless (defined $basic_type_name) {
     confess "Class name not specified";
   }
   
   # Excutable file name
   my $output_file = $self->{output_file};
   unless (defined $output_file) {
-    $output_file = $class_name;
+    $output_file = $basic_type_name;
     $output_file =~ s/::/__/g;
     $self->{output_file} = $output_file;
   }
@@ -154,15 +154,15 @@ sub new {
   }
 
   # Class paths
-  my $class_paths = delete $self->{class_paths};
-  unless (defined $class_paths) {
-    $class_paths = [];
+  my $include_dirs = delete $self->{include_dirs};
+  unless (defined $include_dirs) {
+    $include_dirs = [];
   }
   
   # New SPVM::Builder object
   my $builder = SPVM::Builder->new(
     build_dir => $build_dir,
-    class_paths => $class_paths
+    include_dirs => $include_dirs
   );
   
   # Config file
@@ -179,7 +179,7 @@ sub new {
   else {
     $config = SPVM::Builder::Config::Exe->new_c99(file_optional => 1);
   }
-  $config->class_name($class_name);
+  $config->class_name($basic_type_name);
   
   $self->{config} = $config;
   
@@ -195,7 +195,7 @@ sub build_exe_file {
   my $builder = $self->builder;
   
   # Class name
-  my $class_name = $self->{class_name};
+  my $basic_type_name = $self->{class_name};
   
   # Build runtime
   unless ($self->{finish_compile}) {
@@ -203,7 +203,7 @@ sub build_exe_file {
   }
   
   # Config file
-  my $class_file = $self->runtime->get_class_file($class_name);
+  my $class_file = $self->runtime->get_file($basic_type_name);
 
   # Object files
   my $object_files = [];
@@ -239,7 +239,7 @@ sub build_exe_file {
     category => 'native',
   };
 
-  $cc_linker->link($class_name, $object_files, $options);
+  $cc_linker->link($basic_type_name, $object_files, $options);
 }
 
 sub get_required_resources {
@@ -264,16 +264,16 @@ sub get_required_resources {
     force => $self->force,
   );
   
-  my $class_names = $self->runtime->get_class_names;
-  my $class_names_without_anon = [grep { $_ !~ /::anon::/ } @$class_names];
+  my $basic_type_names = $self->runtime->get_basic_type_names;
+  my $basic_type_names_without_anon = [grep { $_ !~ /::anon::/ } @$basic_type_names];
   my $all_object_files = [];
-  for my $class_name (@$class_names_without_anon) {
+  for my $basic_type_name (@$basic_type_names_without_anon) {
 
-    my $perl_class_name = "SPVM::$class_name";
+    my $perl_class_name = "SPVM::$basic_type_name";
     
-    my $native_method_names = $self->runtime->get_method_names($class_name, 'native');
+    my $native_method_names = $self->runtime->get_method_names($basic_type_name, 'native');
     if (@$native_method_names) {
-      my $native_class_file = $self->runtime->get_class_file($class_name);
+      my $native_class_file = $self->runtime->get_file($basic_type_name);
       my $native_dir = $native_class_file;
       
       $native_dir =~ s/\.spvm$//;
@@ -283,9 +283,9 @@ sub get_required_resources {
       mkpath $build_object_dir;
 
       # Class file
-      my $class_file = $self->runtime->get_class_file($class_name);
+      my $class_file = $self->runtime->get_file($basic_type_name);
       unless (defined $class_file) {
-        my $config_exe_file = SPVM::Builder::Util::get_config_file_from_class_name($class_name);
+        my $config_exe_file = SPVM::Builder::Util::get_config_file_from_class_name($basic_type_name);
         if ($config_exe_file) {
           $class_file = $config_exe_file;
           $class_file =~ s/\.config$/\.spvm/;
@@ -301,7 +301,7 @@ sub get_required_resources {
         my $resource = $config_exe->get_resource($resource_name);
         
         my $resource_info = {
-          class_name => $class_name,
+          class_name => $basic_type_name,
           resource => $resource
         };
         
@@ -320,14 +320,14 @@ sub get_required_resource_json_lines {
   
   my @json_lines;
   for my $required_resource (@$required_resources) {
-    my $class_name = $required_resource->{class_name};
+    my $basic_type_name = $required_resource->{class_name};
     my $resource = $required_resource->{resource};
     my $resource_class_name = $resource->class_name;
     my $resource_mode = $resource->mode;
     my $resource_argv = $resource->argv || [];
     
     my $line = {
-      caller_class_name => "$class_name",
+      caller_class_name => "$basic_type_name",
       resource => {
         class_name => $resource_class_name,
       }
@@ -355,13 +355,13 @@ sub compile {
   my $builder = $self->builder;
   
   # Class name
-  my $class_name = $self->{class_name};
+  my $basic_type_name = $self->{class_name};
   
   # Compile SPVM
   my $compiler = SPVM::Builder::Compiler->new(
-    class_paths => $builder->class_paths
+    include_dirs => $builder->include_dirs
   );
-  my $success = $compiler->compile($class_name, __FILE__, __LINE__);
+  my $success = $compiler->compile($basic_type_name, __FILE__, __LINE__);
   unless ($success) {
     $compiler->print_error_messages(*STDERR);
     exit(255);
@@ -375,15 +375,15 @@ sub compile {
 sub compile_classes {
   my ($self) = @_;
 
-  my $class_names = $self->runtime->get_class_names;
-  my $class_names_without_anon = [grep { $_ !~ /::anon::/ } @$class_names];
+  my $basic_type_names = $self->runtime->get_basic_type_names;
+  my $basic_type_names_without_anon = [grep { $_ !~ /::anon::/ } @$basic_type_names];
   
   my $object_files = [];
-  for my $class_name (@$class_names_without_anon) {
-    my $precompile_object_files = $self->compile_class_precompile_source_file($class_name);
+  for my $basic_type_name (@$basic_type_names_without_anon) {
+    my $precompile_object_files = $self->compile_class_precompile_source_file($basic_type_name);
     push @$object_files, @$precompile_object_files;
     
-    my $native_object_files = $self->compile_class_native_source_files($class_name);
+    my $native_object_files = $self->compile_class_native_source_files($basic_type_name);
     push @$object_files, @$native_object_files;
   }
   
@@ -474,12 +474,12 @@ sub create_bootstrap_header_source {
   my $builder = $self->builder;
 
   # Class name
-  my $class_name = $self->class_name;
+  my $basic_type_name = $self->class_name;
 
   # Class names
-  my $class_names = $self->runtime->get_class_names;
+  my $basic_type_names = $self->runtime->get_basic_type_names;
   
-  my $class_names_without_anon = [grep { $_ !~ /::anon::/ } @$class_names];
+  my $basic_type_names_without_anon = [grep { $_ !~ /::anon::/ } @$basic_type_names];
 
   my $source = '';
 
@@ -503,10 +503,10 @@ EOS
   
   unless ($no_precompile) {
     $source .= "// precompile functions declaration\n";
-    for my $class_name (@$class_names) {
-      my $precompile_method_names = $self->runtime->get_method_names($class_name, 'precompile');
+    for my $basic_type_name (@$basic_type_names) {
+      my $precompile_method_names = $self->runtime->get_method_names($basic_type_name, 'precompile');
       for my $method_name (@$precompile_method_names) {
-        my $class_cname = $class_name;
+        my $class_cname = $basic_type_name;
         $class_cname =~ s/::/__/g;
         $source .= <<"EOS";
 int32_t SPVMPRECOMPILE__${class_cname}__$method_name(SPVM_ENV* env, SPVM_VALUE* stack);
@@ -525,7 +525,7 @@ EOS
   }
   
   $source .= "// native functions declaration\n";
-  for my $class_cname (@$class_names_without_anon) {
+  for my $class_cname (@$basic_type_names_without_anon) {
     my $native_method_names = $self->runtime->get_method_names($class_cname, 'native');
     for my $method_name (@$native_method_names) {
       my $class_cname = $class_cname;
@@ -557,11 +557,11 @@ sub create_bootstrap_main_func_source {
   my $builder = $self->builder;
 
   # Class name
-  my $class_name = $self->class_name;
+  my $basic_type_name = $self->class_name;
 
   # Class names
-  my $class_names = $self->runtime->get_class_names;
-  my $class_names_without_anon = [grep { $_ !~ /::anon::/ } @$class_names];
+  my $basic_type_names = $self->runtime->get_basic_type_names;
+  my $basic_type_names_without_anon = [grep { $_ !~ /::anon::/ } @$basic_type_names];
 
   my $source = '';
 
@@ -627,7 +627,7 @@ int32_t main(int32_t command_args_length, const char *command_args[]) {
   else {
     
     // Class name
-    const char* class_name = "$class_name";
+    const char* class_name = "$basic_type_name";
     
     // Class
     int32_t method_id = env->api->runtime->get_method_id_by_name(env->runtime, class_name, "main");
@@ -697,11 +697,11 @@ sub create_bootstrap_new_env_prepared_func_source {
   my $builder = $self->builder;
   
   # Class name
-  my $class_name = $self->class_name;
+  my $basic_type_name = $self->class_name;
   
   # Class names
-  my $class_names = $self->runtime->get_class_names;
-  my $class_names_without_anon = [grep { $_ !~ /::anon::/ } @$class_names];
+  my $basic_type_names = $self->runtime->get_basic_type_names;
+  my $basic_type_names_without_anon = [grep { $_ !~ /::anon::/ } @$basic_type_names];
   
   my $source = '';
   
@@ -759,21 +759,21 @@ sub create_bootstrap_set_precompile_method_addresses_func_source {
   my $builder = $self->builder;
 
   # Class names
-  my $class_names = $self->runtime->get_class_names;
+  my $basic_type_names = $self->runtime->get_basic_type_names;
 
   my $source = '';
 
   $source .= "static int32_t* SPVM_BOOTSTRAP_create_bootstrap_set_precompile_method_addresses(SPVM_ENV* env){\n";
 
-  for my $class_name (@$class_names) {
-    my $class_cname = $class_name;
+  for my $basic_type_name (@$basic_type_names) {
+    my $class_cname = $basic_type_name;
     $class_cname =~ s/::/__/g;
     
-    my $precompile_method_names = $self->runtime->get_method_names($class_name, 'precompile');
+    my $precompile_method_names = $self->runtime->get_method_names($basic_type_name, 'precompile');
     
     for my $precompile_method_name (@$precompile_method_names) {
       $source .= <<"EOS";
-  SPVM_BOOTSTRAP_set_precompile_method_address(env, "$class_name", "$precompile_method_name", &SPVMPRECOMPILE__${class_cname}__$precompile_method_name);
+  SPVM_BOOTSTRAP_set_precompile_method_address(env, "$basic_type_name", "$precompile_method_name", &SPVMPRECOMPILE__${class_cname}__$precompile_method_name);
 EOS
     }
   }
@@ -790,21 +790,21 @@ sub create_bootstrap_set_native_method_addresses_func_source {
   my $builder = $self->builder;
 
   # Class names
-  my $class_names = $self->runtime->get_class_names;
+  my $basic_type_names = $self->runtime->get_basic_type_names;
 
   my $source = '';
 
   $source .= "static int32_t* SPVM_BOOTSTRAP_create_bootstrap_set_native_method_addresses(SPVM_ENV* env){\n";
 
-  for my $class_name (@$class_names) {
-    my $class_cname = $class_name;
+  for my $basic_type_name (@$basic_type_names) {
+    my $class_cname = $basic_type_name;
     $class_cname =~ s/::/__/g;
     
-    my $native_method_names = $self->runtime->get_method_names($class_name, 'native');
+    my $native_method_names = $self->runtime->get_method_names($basic_type_name, 'native');
     
     for my $native_method_name (@$native_method_names) {
       $source .= <<"EOS";
-  SPVM_BOOTSTRAP_set_native_method_address(env, "$class_name", "$native_method_name", &SPVM__${class_cname}__$native_method_name);
+  SPVM_BOOTSTRAP_set_native_method_address(env, "$basic_type_name", "$native_method_name", &SPVM__${class_cname}__$native_method_name);
 EOS
     }
   }
@@ -821,22 +821,22 @@ sub create_bootstrap_source {
   my $builder = $self->builder;
   
   # Class name
-  my $class_name = $self->class_name;
+  my $basic_type_name = $self->class_name;
   
   # Class names
-  my $class_names = $self->runtime->get_class_names;
-  my $class_names_without_anon = [grep { $_ !~ /::anon::/ } @$class_names];
+  my $basic_type_names = $self->runtime->get_basic_type_names;
+  my $basic_type_names_without_anon = [grep { $_ !~ /::anon::/ } @$basic_type_names];
   
   # Class files - Input
   my $class_files = [];
-  for my $class_name (@$class_names_without_anon) {
-    my $class_file = $self->runtime->get_class_file($class_name);
+  for my $basic_type_name (@$basic_type_names_without_anon) {
+    my $class_file = $self->runtime->get_file($basic_type_name);
     push @$class_files, $class_file;
   }
   
   # Source file - Output
   my $build_src_dir = SPVM::Builder::Util::create_build_src_path($self->builder->build_dir);
-  my $target_perl_class_name = "SPVM::$class_name";
+  my $target_perl_class_name = "SPVM::$basic_type_name";
   my $bootstrap_base = $target_perl_class_name;
   $bootstrap_base =~ s|::|/|g;
   my $bootstrap_source_file = "$build_src_dir/$bootstrap_base.boot.c";
@@ -893,14 +893,14 @@ sub compile_bootstrap_source_file {
   my $config_exe = $self->config;
   
   # Target class name
-  my $class_name = $self->class_name;
+  my $basic_type_name = $self->class_name;
   
-  my $target_perl_class_name = "SPVM::$class_name";
+  my $target_perl_class_name = "SPVM::$basic_type_name";
   
   # Compile source files
-  my $class_name_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file($target_perl_class_name);
-  my $object_file_name = SPVM::Builder::Util::create_build_object_path($self->builder->build_dir, "$class_name_rel_file.boot.o");
-  my $source_file = SPVM::Builder::Util::create_build_src_path($self->builder->build_dir, "$class_name_rel_file.boot.c");
+  my $basic_type_name_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file($target_perl_class_name);
+  my $object_file_name = SPVM::Builder::Util::create_build_object_path($self->builder->build_dir, "$basic_type_name_rel_file.boot.o");
+  my $source_file = SPVM::Builder::Util::create_build_src_path($self->builder->build_dir, "$basic_type_name_rel_file.boot.c");
   
   # Create directory for object file output
   mkdir dirname $object_file_name;
@@ -976,7 +976,7 @@ sub compile_spvm_core_source_files {
 }
 
 sub compile_class_precompile_source_file {
-  my ($self, $class_name) = @_;
+  my ($self, $basic_type_name) = @_;
 
   my $config_exe = $self->config;
   
@@ -998,16 +998,16 @@ sub compile_class_precompile_source_file {
   );
   
   my $object_files = [];
-  my $precompile_method_names = $self->runtime->get_method_names($class_name, 'precompile');
+  my $precompile_method_names = $self->runtime->get_method_names($basic_type_name, 'precompile');
   if (@$precompile_method_names) {
     my $build_src_dir = SPVM::Builder::Util::create_build_src_path($self->builder->build_dir);
     mkpath $build_src_dir;
     
-    my $class_file = $self->runtime->get_class_file($class_name);
-    my $precompile_source = $self->runtime->build_precompile_class_source($class_name);
+    my $class_file = $self->runtime->get_file($basic_type_name);
+    my $precompile_source = $self->runtime->build_precompile_source($basic_type_name);
     
-    $builder_cc->build_precompile_class_source_file(
-      $class_name,
+    $builder_cc->build_precompile_source_file(
+      $basic_type_name,
       {
         output_dir => $build_src_dir,
         precompile_source => $precompile_source,
@@ -1022,7 +1022,7 @@ sub compile_class_precompile_source_file {
     my $before_each_compile_cbs = $config_exe->before_each_compile_cbs;
     $config->add_before_compile_cb(@$before_each_compile_cbs);
     my $precompile_object_files = $builder_cc->compile_source_files(
-      $class_name,
+      $basic_type_name,
       {
         input_dir => $build_src_dir,
         output_dir => $build_object_dir,
@@ -1037,7 +1037,7 @@ sub compile_class_precompile_source_file {
 }
 
 sub compile_class_native_source_files {
-  my ($self, $class_name) = @_;
+  my ($self, $basic_type_name) = @_;
 
   my $config_exe = $self->config;
   
@@ -1056,11 +1056,11 @@ sub compile_class_native_source_files {
   
   my $all_object_files = [];
   
-  my $perl_class_name = "SPVM::$class_name";
+  my $perl_class_name = "SPVM::$basic_type_name";
   
-  my $native_method_names = $self->runtime->get_method_names($class_name, 'native');
+  my $native_method_names = $self->runtime->get_method_names($basic_type_name, 'native');
   if (@$native_method_names) {
-    my $native_class_file = $self->runtime->get_class_file($class_name);
+    my $native_class_file = $self->runtime->get_file($basic_type_name);
     my $native_dir = $native_class_file;
     
     $native_dir =~ s/\.spvm$//;
@@ -1070,9 +1070,9 @@ sub compile_class_native_source_files {
     mkpath $build_object_dir;
 
     # Class file
-    my $class_file = $self->runtime->get_class_file($class_name);
+    my $class_file = $self->runtime->get_file($basic_type_name);
     unless (defined $class_file) {
-      my $config_file = SPVM::Builder::Util::get_config_file_from_class_name($class_name);
+      my $config_file = SPVM::Builder::Util::get_config_file_from_class_name($basic_type_name);
       if ($config_file) {
         $class_file = $config_file;
         $class_file =~ s/\.config$/\.spvm/;
@@ -1097,7 +1097,7 @@ sub compile_class_native_source_files {
     
     $config->disable_resource(1);
     my $object_files = $builder_cc->compile_source_files(
-      $class_name,
+      $basic_type_name,
       {
         input_dir => $input_dir,
         output_dir => $build_object_dir,
