@@ -164,7 +164,7 @@ sub spurt_binary {
 }
 
 sub create_cfunc_name {
-  my ($class_name, $method_name, $category) = @_;
+  my ($basic_type_name, $method_name, $category) = @_;
   
   my $prefix;
   if ($category eq 'native') {
@@ -175,7 +175,7 @@ sub create_cfunc_name {
   }
   
   # Precompile Method names
-  my $method_abs_name_under_score = "${class_name}::$method_name";
+  my $method_abs_name_under_score = "${basic_type_name}::$method_name";
   $method_abs_name_under_score =~ s/:/_/g;
   my $cfunc_name = "$prefix$method_abs_name_under_score";
   
@@ -221,21 +221,21 @@ sub convert_class_file_to_dynamic_lib_file {
 }
 
 sub convert_class_name_to_dynamic_lib_rel_file {
-  my ($class_name, $category) = @_;
+  my ($basic_type_name, $category) = @_;
   
   my $dlext = $Config{dlext};
-  my $dynamic_lib_category_rel_file = convert_class_name_to_rel_file($class_name);
+  my $dynamic_lib_category_rel_file = convert_class_name_to_rel_file($basic_type_name);
   $dynamic_lib_category_rel_file .= $category eq 'native' ? ".$dlext" : ".$category.$dlext";
   
   return $dynamic_lib_category_rel_file;
 }
 
 sub convert_class_name_to_category_rel_file {
-  my ($class_name, $category, $ext) = @_;
+  my ($basic_type_name, $category, $ext) = @_;
   
-  $class_name =~ s/^SPVM:://;
+  $basic_type_name =~ s/^SPVM:://;
   
-  my $rel_file_with_ext = "SPVM::$class_name";
+  my $rel_file_with_ext = "SPVM::$basic_type_name";
   $rel_file_with_ext =~ s/::/\//g;
   $rel_file_with_ext .= $category eq 'native' ? "" : ".$category";
   if (defined $ext) {
@@ -246,12 +246,12 @@ sub convert_class_name_to_category_rel_file {
 }
 
 sub convert_class_name_to_rel_dir {
-  my ($class_name) = @_;
+  my ($basic_type_name) = @_;
 
-  $class_name =~ s/^SPVM:://;
+  $basic_type_name =~ s/^SPVM:://;
 
   my $rel_dir;
-  my $rel_file = "SPVM::$class_name";
+  my $rel_file = "SPVM::$basic_type_name";
   $rel_file =~ s/::/\//g;
   $rel_dir = dirname $rel_file;
   
@@ -259,11 +259,11 @@ sub convert_class_name_to_rel_dir {
 }
 
 sub convert_class_name_to_rel_file {
-  my ($class_name, $ext) = @_;
+  my ($basic_type_name, $ext) = @_;
 
-  $class_name =~ s/^SPVM:://;
+  $basic_type_name =~ s/^SPVM:://;
   
-  my $rel_file_with_ext = "SPVM::$class_name";
+  my $rel_file_with_ext = "SPVM::$basic_type_name";
   $rel_file_with_ext =~ s/::/\//g;
   
   if (defined $ext) {
@@ -274,12 +274,12 @@ sub convert_class_name_to_rel_file {
 }
 
 sub remove_class_part_from_file {
-  my ($file, $class_name) = @_;
+  my ($file, $basic_type_name) = @_;
 
-  $class_name =~ s/^SPVM:://;
+  $basic_type_name =~ s/^SPVM:://;
   
   $file =~ s/\.spvm$//;
-  my $class_file = "SPVM::$class_name";
+  my $class_file = "SPVM::$basic_type_name";
   $class_file =~ s/::/\//g;
   $file =~ s/$class_file$//;
   $file =~ s/[\\\/]$//;
@@ -288,29 +288,29 @@ sub remove_class_part_from_file {
 }
 
 sub create_make_rule_native {
-  my $class_name = shift;
+  my $basic_type_name = shift;
   
-  create_make_rule($class_name, 'native', @_);
+  create_make_rule($basic_type_name, 'native', @_);
 }
 
 sub create_make_rule_precompile {
-  my $class_name = shift;
+  my $basic_type_name = shift;
   
-  create_make_rule($class_name, 'precompile', @_);
+  create_make_rule($basic_type_name, 'precompile', @_);
 }
 
 sub create_make_rule {
-  my ($class_name, $category, $options) = @_;
+  my ($basic_type_name, $category, $options) = @_;
   
   $options ||= {};
-  $class_name =~ s/^SPVM:://;
+  $basic_type_name =~ s/^SPVM:://;
   
-  my $class_base_name = $class_name;
+  my $class_base_name = $basic_type_name;
   $class_base_name =~ s/^.+:://;
   
   my $lib_dir = defined $options->{lib_dir} ? $options->{lib_dir} : 'lib';
   
-  my $class_rel_file = convert_class_name_to_rel_file($class_name, 'spvm');
+  my $class_rel_file = convert_class_name_to_rel_file($basic_type_name, 'spvm');
   
   my $noext_file = $class_rel_file;
   $noext_file =~ s/\.[^\.]+$//;
@@ -361,7 +361,7 @@ sub create_make_rule {
   }
   
   # Shared library file
-  my $dynamic_lib_rel_file = convert_class_name_to_dynamic_lib_rel_file($class_name, $category);
+  my $dynamic_lib_rel_file = convert_class_name_to_dynamic_lib_rel_file($basic_type_name, $category);
   my $dynamic_lib_file = "blib/lib/$dynamic_lib_rel_file";
   
   my $make_rule = '';
@@ -372,7 +372,7 @@ sub create_make_rule {
   
   # Get source files
   $make_rule .= "$dynamic_lib_file :: @deps\n";
-  $make_rule .= "\t$^X -Mblib -MSPVM::Builder::API -e \"SPVM::Builder::API->new(build_dir => '.spvm_build')->build_dynamic_lib_dist_$category('$class_name')\"\n\n";
+  $make_rule .= "\t$^X -Mblib -MSPVM::Builder::API -e \"SPVM::Builder::API->new(build_dir => '.spvm_build')->build_dynamic_lib_dist_$category('$basic_type_name')\"\n\n";
   
   return $make_rule;
 }
@@ -536,14 +536,14 @@ sub get_spvm_core_header_file_names {
 }
 
 sub get_config_file_from_class_name {
-  my ($class_name, $mode) = @_;
+  my ($basic_type_name, $mode) = @_;
   
   my $ext = 'config';
   if (defined $mode) {
     $ext = "$mode.$ext";
   }
   
-  my $config_file_base = SPVM::Builder::Util::convert_class_name_to_rel_file($class_name, $ext);
+  my $config_file_base = SPVM::Builder::Util::convert_class_name_to_rel_file($basic_type_name, $ext);
   my $config_file;
   for my $inc (@INC) {
     my $config_file_tmp = "$inc/$config_file_base";
@@ -611,7 +611,7 @@ sub create_build_lib_path {
 }
 
 sub create_dl_func_list {
-  my ($class_name, $method_names, $anon_class_names, $options) = @_;
+  my ($basic_type_name, $method_names, $anon_class_names, $options) = @_;
   
   $options ||= {};
   
@@ -621,7 +621,7 @@ sub create_dl_func_list {
   # This option is needed Windows DLL file
   my $dl_func_list = [];
   for my $method_name (@$method_names) {
-    my $cfunc_name = SPVM::Builder::Util::create_cfunc_name($class_name, $method_name, $category);
+    my $cfunc_name = SPVM::Builder::Util::create_cfunc_name($basic_type_name, $method_name, $category);
     push @$dl_func_list, $cfunc_name;
   }
   
@@ -649,14 +649,14 @@ sub get_dynamic_lib_file_dist {
 }
 
 sub get_method_addresses {
-  my ($dynamic_lib_file, $class_name, $method_names, $anon_class_names, $category) = @_;
+  my ($dynamic_lib_file, $basic_type_name, $method_names, $anon_class_names, $category) = @_;
   
   my $method_addresses = {};
   if (@$method_names) {
     my $method_infos = [];
     for my $method_name (@$method_names) {
       my $method_info = {};
-      $method_info->{class_name} = $class_name;
+      $method_info->{class_name} = $basic_type_name;
       $method_info->{method_name} = $method_name;
       push @$method_infos, $method_info;
     }
@@ -672,7 +672,7 @@ sub get_method_addresses {
     }
     
     for my $method_info (@$method_infos) {
-      my $class_name = $method_info->{class_name};
+      my $basic_type_name = $method_info->{class_name};
       my $method_name = $method_info->{method_name};
 
       my $cfunc_address;
@@ -681,12 +681,12 @@ sub get_method_addresses {
         
         if ($dynamic_lib_libref) {
 
-          my $cfunc_name = SPVM::Builder::Util::create_cfunc_name($class_name, $method_name, $category);
+          my $cfunc_name = SPVM::Builder::Util::create_cfunc_name($basic_type_name, $method_name, $category);
           $cfunc_address = DynaLoader::dl_find_symbol($dynamic_lib_libref, $cfunc_name);
           unless ($cfunc_address) {
             my $dl_error = DynaLoader::dl_error();
             my $error = <<"EOS";
-Can't find native function \"$cfunc_name\" corresponding to ${class_name}->$method_name in \"$dynamic_lib_file\"
+Can't find native function \"$cfunc_name\" corresponding to ${basic_type_name}->$method_name in \"$dynamic_lib_file\"
 
 You must write the following definition.
 --------------------------------------------------
@@ -705,7 +705,7 @@ EOS
         }
         else {
           my $dl_error = DynaLoader::dl_error();
-          confess "The DynaLoader::dl_load_file function failed:Can't load the \"$dynamic_lib_file\" file for the $category methods in the $class_name class: $dl_error";
+          confess "The DynaLoader::dl_load_file function failed:Can't load the \"$dynamic_lib_file\" file for the $category methods in the $basic_type_name class: $dl_error";
         }
       }
       else {
