@@ -17,9 +17,9 @@ struct spvm_basic_type {
   SPVM_OP* op_class;
   SPVM_OP* op_name;
   SPVM_OP* op_extends;
-  const char* class_file;
-  const char* class_path;
-  const char* class_rel_file;
+  const char* file;
+  const char* dir;
+  const char* rel_file;
   const char* version_string;
   SPVM_TYPE* type;
   SPVM_LIST* class_vars;
@@ -34,14 +34,13 @@ struct spvm_basic_type {
   SPVM_LIST* anon_methods;
   SPVM_LIST* allows;
   SPVM_LIST* interface_decls;
-  SPVM_LIST* use_class_names;
-  SPVM_HASH* class_alias_symtable;
+  SPVM_LIST* use_basic_type_names;
+  SPVM_HASH* alias_symtable;
   SPVM_METHOD* required_method;
   SPVM_METHOD* destructor_method;
   SPVM_METHOD* init_method;
-  const char* parent_class_name;
-  SPVM_BASIC_TYPE* parent_class_basic_type;
-  int32_t class_id;
+  const char* parent_name;
+  SPVM_BASIC_TYPE* parent;
   int32_t merged_fields_original_offset;
   int32_t fields_size;
   int8_t has_init_block;
@@ -56,7 +55,7 @@ SPVM_BASIC_TYPE* SPVM_BASIC_TYPE_new(SPVM_COMPILER* compiler);
 
 const char* const* SPVM_BASIC_TYPE_C_ID_NAMES(void);
 
-const char* SPVM_BASIC_TYPE_get_basic_type_name(int32_t basic_type_id);
+const char* SPVM_BASIC_TYPE_get_basic_type_name(SPVM_COMPILER* compiler, int32_t basic_type_id);
 
 int32_t SPVM_BASIC_TYPE_is_void_type(SPVM_COMPILER* compiler, int32_t basic_type_id);
 
@@ -76,8 +75,6 @@ int32_t SPVM_BASIC_TYPE_is_undef_type(SPVM_COMPILER* compiler, int32_t basic_typ
 
 int32_t SPVM_BASIC_TYPE_is_unknown_type(SPVM_COMPILER* compiler, int32_t basic_type_id);
 
-int32_t SPVM_BASIC_TYPE_is_not_found_class_type(SPVM_COMPILER* compiler, int32_t basic_type_id);
-
 int32_t SPVM_BASIC_TYPE_is_numeric_object_type(SPVM_COMPILER* compiler, int32_t basic_type_id);
 
 int32_t SPVM_BASIC_TYPE_is_integer_type(SPVM_COMPILER* compiler, int32_t basic_type_id);
@@ -86,6 +83,6 @@ int32_t SPVM_BASIC_TYPE_is_integer_type_within_int(SPVM_COMPILER* compiler, int3
 
 int32_t SPVM_BASIC_TYPE_has_interface(SPVM_COMPILER* compiler, int32_t class_basic_type_id, int32_t interface_basic_type_id);
 
-int32_t SPVM_BASIC_TYPE_is_super_class(SPVM_COMPILER* compiler, int32_t super_basic_type_id, int32_t child_basic_type_id);
+int32_t SPVM_BASIC_TYPE_is_super(SPVM_COMPILER* compiler, int32_t super_basic_type_id, int32_t child_basic_type_id);
 
 #endif
