@@ -9,7 +9,7 @@
 struct spvm_class_var {
   const char* name;
   SPVM_TYPE* type;
-  SPVM_BASIC_TYPE* class_basic_type;
+  SPVM_BASIC_TYPE* current_basic_type;
   SPVM_OP* op_class_var;
   SPVM_OP* op_name;
   int32_t id;
