@@ -15,7 +15,7 @@ struct spvm_compiler {
   SPVM_LIST* ops;
   
   // Class paths
-  SPVM_LIST* class_paths;
+  SPVM_LIST* include_dirs;
   
   // Class loading stack
   SPVM_LIST* op_use_stack;
@@ -24,7 +24,7 @@ struct spvm_compiler {
   SPVM_LIST* op_types;
   
   // Directory of curreparsed file
-  const char* cur_class_path;
+  const char* cur_include_dir;
   
   // Current parsed file name
   const char* cur_file;
@@ -33,7 +33,7 @@ struct spvm_compiler {
   const char* cur_rel_file;
   
   // Current parsed class name
-  const char* cur_rel_file_class_name;
+  const char* cur_rel_file_basic_type_name;
   
   // Current parsed source
   char* cur_source;
@@ -102,10 +102,10 @@ struct spvm_compiler {
   SPVM_STRING_BUFFER* constant_strings_buffer;
   
   // Used class symtable
-  SPVM_HASH* used_class_name_symtable;
-
+  SPVM_HASH* used_basic_type_name_symtable;
+  
   // Fail load class symtable
-  SPVM_HASH* not_found_class_name_symtable;
+  SPVM_HASH* if_require_not_found_basic_type_name_symtable;
   
   // Operation codes
   SPVM_OPCODE_ARRAY* opcode_array;
@@ -143,8 +143,9 @@ struct spvm_compiler {
 
 SPVM_COMPILER* SPVM_COMPILER_new();
 void SPVM_COMPILER_free(SPVM_COMPILER* compiler);
-void SPVM_COMPILER_add_source(SPVM_COMPILER* compiler, const char* class_name, const char* source, int32_t length);
-void SPVM_COMPILER_add_basic_type(SPVM_COMPILER* compiler, int32_t basic_type_id, int32_t basic_type_category);
+void SPVM_COMPILER_add_source(SPVM_COMPILER* compiler, const char* basic_type_name, const char* source, int32_t length);
+void SPVM_COMPILER_add_basic_type_core(SPVM_COMPILER* compiler, int32_t basic_type_id, int32_t basic_type_category);
+SPVM_BASIC_TYPE* SPVM_COMPILER_add_basic_type(SPVM_COMPILER* compiler, const char* basic_type_name);
 void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler);
 SPVM_RUNTIME* SPVM_COMPILER_new_object(SPVM_COMPILER* compiler);
 void SPVM_COMPILER_error(SPVM_COMPILER* compiler, const char* message, ...);
@@ -156,15 +157,15 @@ void SPVM_COMPILER_set_start_file(SPVM_COMPILER* compiler, const char* start_fil
 int32_t SPVM_COMPILER_get_start_line(SPVM_COMPILER* compiler);
 void SPVM_COMPILER_set_start_line(SPVM_COMPILER* compiler, int32_t start_line);
 
-void SPVM_COMPILER_add_class_path(SPVM_COMPILER* compiler, const char* class_path);
-int32_t SPVM_COMPILER_get_class_paths_length(SPVM_COMPILER* compiler);
-const char* SPVM_COMPILER_get_class_path(SPVM_COMPILER* compiler, int32_t index);
-void SPVM_COMPILER_clear_class_paths(SPVM_COMPILER* compiler);
+void SPVM_COMPILER_add_include_dir(SPVM_COMPILER* compiler, const char* include_dir);
+int32_t SPVM_COMPILER_get_include_dirs_length(SPVM_COMPILER* compiler);
+const char* SPVM_COMPILER_get_include_dir(SPVM_COMPILER* compiler, int32_t index);
+void SPVM_COMPILER_clear_include_dirs(SPVM_COMPILER* compiler);
 
 int32_t SPVM_COMPILER_get_error_messages_length(SPVM_COMPILER* compiler);
 const char* SPVM_COMPILER_get_error_message(SPVM_COMPILER* compiler, int32_t index);
 
-int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name);
+int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* basic_type_name);
 
 int32_t SPVM_COMPILER_calculate_runtime_codes_length(SPVM_COMPILER* compiler);
 int32_t* SPVM_COMPILER_create_runtime_codes(SPVM_COMPILER* compiler, SPVM_ALLOCATOR* allocator);
