@@ -16,8 +16,8 @@ struct spvm_method {
   SPVM_LIST* var_decls;
   SPVM_LIST* anon_method_fields;
   const char* abs_name;
-  SPVM_BASIC_TYPE* class_basic_type;
-  const char* anon_method_defined_class_name;
+  SPVM_BASIC_TYPE* current_basic_type;
+  const char* anon_method_defined_basic_type_name;
   int32_t enum_value;
   int32_t args_length;
   int32_t required_args_length;
@@ -35,7 +35,7 @@ struct spvm_method {
   int32_t mortal_stack_length;
   int32_t anon_method_id;
   int32_t tmp_vars_length;
-  int8_t is_class_method;
+  int8_t is_static;
   int8_t is_init;
   int8_t is_destructor;
   int8_t is_enum;
