@@ -115,8 +115,8 @@ struct spvm_env {
   int32_t (*get_basic_type_id)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name);
   int32_t (*get_field_id)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* field_name);
   int32_t (*get_field_offset)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t field_id);
-  int32_t (*get_class_var_id)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name);
-  int32_t (*get_class_method_id)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* method_name);
+  int32_t (*get_class_var_id)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name);
+  int32_t (*get_class_method_id)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* method_name);
   int32_t (*get_instance_method_id)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* method_name);
   void* (*new_object_raw)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t basic_type_id);
   void* (*new_object)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t basic_type_id);
@@ -212,7 +212,7 @@ struct spvm_env {
   void* memory_blocks_count;
   const char* (*get_chars)(SPVM_ENV* env, SPVM_VALUE* stack, void* string_object);
   int32_t (*die)(SPVM_ENV* env, SPVM_VALUE* stack, const char* message, ...);
-  void* (*new_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, int32_t* error, const char* func_name, const char* file, int32_t line);
+  void* (*new_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, int32_t* error, const char* func_name, const char* file, int32_t line);
   void (*set_field_byte_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* field_name, int8_t value, int32_t* error, const char* func_name, const char* file, int32_t line);
   void (*set_field_short_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* field_name, int16_t value, int32_t* error, const char* func_name, const char* file, int32_t line);
   void (*set_field_int_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* field_name, int32_t value, int32_t* error, const char* func_name, const char* file, int32_t line);
@@ -227,27 +227,27 @@ struct spvm_env {
   float (*get_field_float_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* field_name, int32_t* error, const char* func_name, const char* file, int32_t line);
   double (*get_field_double_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* field_name, int32_t* error, const char* func_name, const char* file, int32_t line);
   void* (*get_field_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* field_name, int32_t* error, const char* func_name, const char* file, int32_t line);
-  void (*set_class_var_byte_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, int8_t value, int32_t* error, const char* func_name, const char* file, int32_t line);
-  void (*set_class_var_short_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, int16_t value, int32_t* error, const char* func_name, const char* file, int32_t line);
-  void (*set_class_var_int_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, int32_t value, int32_t* error, const char* func_name, const char* file, int32_t line);
-  void (*set_class_var_long_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, int64_t value, int32_t* error, const char* func_name, const char* file, int32_t line);
-  void (*set_class_var_float_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, float value, int32_t* error, const char* func_name, const char* file, int32_t line);
-  void (*set_class_var_double_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, double value, int32_t* error, const char* func_name, const char* file, int32_t line);
-  void (*set_class_var_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, void* value, int32_t* error, const char* func_name, const char* file, int32_t line);
-  int8_t (*get_class_var_byte_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
-  int16_t (*get_class_var_short_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
-  int32_t (*get_class_var_int_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
-  int64_t (*get_class_var_long_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
-  float (*get_class_var_float_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
-  double (*get_class_var_double_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
-  void* (*get_class_var_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
-  int32_t (*call_class_method_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* method_name, int32_t args_stack_length, const char* func_name, const char* file, int32_t line);
+  void (*set_class_var_byte_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, int8_t value, int32_t* error, const char* func_name, const char* file, int32_t line);
+  void (*set_class_var_short_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, int16_t value, int32_t* error, const char* func_name, const char* file, int32_t line);
+  void (*set_class_var_int_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, int32_t value, int32_t* error, const char* func_name, const char* file, int32_t line);
+  void (*set_class_var_long_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, int64_t value, int32_t* error, const char* func_name, const char* file, int32_t line);
+  void (*set_class_var_float_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, float value, int32_t* error, const char* func_name, const char* file, int32_t line);
+  void (*set_class_var_double_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, double value, int32_t* error, const char* func_name, const char* file, int32_t line);
+  void (*set_class_var_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, void* value, int32_t* error, const char* func_name, const char* file, int32_t line);
+  int8_t (*get_class_var_byte_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
+  int16_t (*get_class_var_short_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
+  int32_t (*get_class_var_int_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
+  int64_t (*get_class_var_long_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
+  float (*get_class_var_float_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
+  double (*get_class_var_double_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
+  void* (*get_class_var_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* class_var_name, int32_t* error, const char* func_name, const char* file, int32_t line);
+  int32_t (*call_class_method_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* method_name, int32_t args_stack_length, const char* func_name, const char* file, int32_t line);
   int32_t (*call_instance_method_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* method_name, int32_t args_stack_length, const char* func_name, const char* file, int32_t line);
   const char* (*get_field_string_chars_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* field_name, int32_t* error, const char* func_name, const char* file, int32_t line);
   void (*free_env_prepared)(SPVM_ENV* env);
   void* (*dump_raw)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
   void* (*dump)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
-  int32_t (*get_instance_method_id_static)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* method_name);
+  int32_t (*get_instance_method_id_static)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* method_name);
   int32_t (*get_bool_object_value)(SPVM_ENV* env, SPVM_VALUE* stack, void* bool_object);
   void (*cleanup_global_vars)(SPVM_ENV* env, SPVM_VALUE* stack);
   void (*make_read_only)(SPVM_ENV* env, SPVM_VALUE* stack, void* string);
@@ -286,17 +286,17 @@ struct spvm_env {
   const char* (*dumpc)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
   void* (*new_pointer_object_raw)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t basic_type_id, void* pointer);
   void* (*new_pointer_object)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t basic_type_id, void* pointer);
-  void* (*new_pointer_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, void* pointer, int32_t* error, const char* func_name, const char* file, int32_t line);
+  void* (*new_pointer_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, void* pointer, int32_t* error, const char* func_name, const char* file, int32_t line);
   void* (*get_elem_string)(SPVM_ENV* env, SPVM_VALUE* stack, void* array, int32_t index);
   void (*set_elem_string)(SPVM_ENV* env, SPVM_VALUE* stack, void* array, int32_t index, void* string);
   int32_t (*is_class)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
   int32_t (*is_pointer_class)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
   void* (*strerror_string)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t errno_value, int32_t length);
   int32_t (*get_basic_type_id_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, int32_t* error, const char* func_name, const char* file, int32_t line);
-  int32_t (*get_field_id_static)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* field_name);
+  int32_t (*get_field_id_static)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* field_name);
   int32_t (*items)(SPVM_ENV* env, SPVM_VALUE* stack);
-  int32_t (*call_instance_method_static_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* method_name, int32_t args_stack_length, const char* func_name, const char* file, int32_t line);
-  int32_t (*get_method_id)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* method_name);
+  int32_t (*call_instance_method_static_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* method_name, int32_t args_stack_length, const char* func_name, const char* file, int32_t line);
+  int32_t (*get_method_id)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, const char* method_name);
   const char* (*strerror_nolen)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t errno_value);
   void* (*strerror_string_nolen)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t errno_value);
   void* (*get_compile_type_name_raw)(SPVM_ENV* env, SPVM_VALUE* stack, const char* basic_type_name, int32_t dimension, int32_t flag);
@@ -307,7 +307,7 @@ struct spvm_env {
   const char* (*get_version_string)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t basic_type_id);
   double (*get_version_number)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t basic_type_id);
   int32_t (*call_method)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t method_id, int32_t args_stack_length);
-  void* class_init_flags;
+  void* init_flags;
   const char* (*get_object_basic_type_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
   int32_t (*isa_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* basic_type_name, int32_t type_dimension);
   int32_t (*is_type_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, const char* basic_type_name, int32_t type_dimension);
@@ -351,20 +351,20 @@ struct spvm_env_runtime {
   void* reserved30;
   void* reserved31;
   int32_t (*get_class_var_id_by_index)(void* runtime, int32_t basic_type_id, int32_t class_var_index);
-  int32_t (*get_class_var_id_by_name)(void* runtime, const char* class_name, const char* class_var_name);
+  int32_t (*get_class_var_id_by_name)(void* runtime, const char* basic_type_name, const char* class_var_name);
   int32_t (*get_class_var_name_id)(void* runtime, int32_t class_var_id);
   void* reserved35;
   int32_t (*get_field_id_by_index)(void* runtime, int32_t basic_type_id, int32_t field_index);
-  int32_t (*get_field_id_by_name)(void* runtime, const char* class_name, const char* field_name);
+  int32_t (*get_field_id_by_name)(void* runtime, const char* basic_type_name, const char* field_name);
   int32_t (*get_field_name_id)(void* runtime, int32_t field_id);
   void* reserved39;
   void* reserved40;
   int32_t (*get_method_id_by_index)(void* runtime, int32_t basic_type_id, int32_t method_index);
-  int32_t (*get_method_id_by_name)(void* runtime, const char* class_name, const char* method_name);
+  int32_t (*get_method_id_by_name)(void* runtime, const char* basic_type_name, const char* method_name);
   int32_t (*get_method_name_id)(void* runtime, int32_t method_id);
   void* reserved44;
   void* reserved45;
-  int32_t (*get_method_is_class_method)(void* runtime, int32_t method_id);
+  int32_t (*get_method_is_static)(void* runtime, int32_t method_id);
   int32_t (*get_method_is_anon)(void* runtime, int32_t method_id);
   int32_t (*get_method_is_native)(void* runtime, int32_t method_id);
   int32_t (*get_method_is_precompile)(void* runtime, int32_t method_id);
@@ -403,9 +403,9 @@ struct spvm_env_runtime {
   void* reserved82;
   int32_t (*is_object_type)(void* runtime, int32_t basic_type_id, int32_t type_dimension, int32_t flag);
   void* reserved84;
-  void* class_init_flags;
-  int32_t (*can_assign)(void* runtime, int32_t dist_basic_type_id, int32_t dist_type_dimension, int32_t dist_type_flag, int32_t src_basic_type_id, int32_t src_type_dimension, int32_t src_type_flag);  int32_t (*get_basic_type_class_rel_file_id)(void* runtime, int32_t basic_type_id);
-  int32_t (*get_basic_type_class_path_id)(void* runtime, int32_t basic_type_id);
+  void* init_flags;
+  int32_t (*can_assign)(void* runtime, int32_t dist_basic_type_id, int32_t dist_type_dimension, int32_t dist_type_flag, int32_t src_basic_type_id, int32_t src_type_dimension, int32_t src_type_flag);  int32_t (*get_basic_type_rel_file_id)(void* runtime, int32_t basic_type_id);
+  int32_t (*get_basic_type_dir_id)(void* runtime, int32_t basic_type_id);
   int32_t (*get_basic_type_is_anon)(void* runtime, int32_t basic_type_id);
   int32_t (*get_basic_type_fields_base_id)(void* runtime, int32_t basic_type_id);
   int32_t (*get_basic_type_fields_length)(void* runtime, int32_t basic_type_id);
@@ -415,7 +415,7 @@ struct spvm_env_runtime {
   int32_t (*get_basic_type_class_vars_length)(void* runtime, int32_t basic_type_id);
   int32_t (*get_basic_type_anon_methods_base_id)(void* runtime, int32_t basic_type_id);
   int32_t (*get_basic_type_anon_methods_length)(void* runtime, int32_t basic_type_id);
-  int32_t (*get_basic_type_is_class)(void* runtime, int32_t basic_type_id);
+  void* reserved98;
   int32_t (*get_basic_types_length)(void* runtime);
   int32_t (*get_field_basic_type_id)(void* runtime, int32_t field_id);
   int32_t (*get_field_type_dimension)(void* runtime, int32_t field_id);
@@ -429,9 +429,9 @@ struct spvm_env_runtime {
   int32_t (*get_arg_basic_type_id)(void* runtime, int32_t arg_id);
   int32_t (*get_arg_type_dimension)(void* runtime, int32_t arg_id);
   int32_t (*get_arg_type_flag)(void* runtime, int32_t arg_id);
-  int32_t (*get_method_class_basic_type_id)(void* runtime, int32_t method_id);
-  int32_t (*get_field_class_basic_type_id)(void* runtime, int32_t method_id);
-  int32_t (*get_class_var_class_basic_type_id)(void* runtime, int32_t method_id);
+  int32_t (*get_method_current_basic_type_id)(void* runtime, int32_t method_id);
+  int32_t (*get_field_current_basic_type_id)(void* runtime, int32_t method_id);
+  int32_t (*get_class_var_current_basic_type_id)(void* runtime, int32_t method_id);
   int32_t (*get_basic_type_parent_class_basic_type_id)(void* runtime, int32_t basic_type_id);
   int32_t (*get_basic_type_version_string_id)(void* runtime, int32_t basic_type_id);
 };
@@ -443,14 +443,14 @@ struct spvm_env_compiler {
   int32_t (*get_start_line)(void* compiler);
   void (*set_start_file)(void* compiler, const char* start_file);
   const char* (*get_start_file)(void* compiler);
-  void (*add_class_path)(void* compiler, const char* class_path);
-  int32_t (*get_class_paths_length )(void* compiler);
-  const char* (*get_class_path )(void* compiler, int32_t index);
-  int32_t (*compile)(void* compiler, const char* class_name);
+  void (*add_include_dir)(void* compiler, const char* include_dir);
+  int32_t (*get_include_dirs_length )(void* compiler);
+  const char* (*get_include_dir )(void* compiler, int32_t index);
+  int32_t (*compile)(void* compiler, const char* basic_type_name);
   int32_t (*get_error_messages_length)(void* compiler);
   const char* (*get_error_message)(void* compiler, int32_t index);
   int32_t* (*create_runtime_codes)(void* compiler, void* allocator);
-  void (*clear_class_paths)(void* compiler);
+  void (*clear_include_dirs)(void* compiler);
 };
 
 struct spvm_env_precompile {
@@ -458,8 +458,8 @@ struct spvm_env_precompile {
   void (*free_object)(void* precompile);
   void (*set_runtime)(void* precompile, void* runtime);
   void* (*get_runtime)(void* precompile);
-  void (*build_class_source)(void* precompile, void* string_buffer, const char* class_name);
-  void (*build_method_source)(void* precompile, void* string_buffer, const char* class_name, const char* method_name);
+  void (*build_source)(void* precompile, void* string_buffer, const char* basic_type_name);
+  void (*build_method_source)(void* precompile, void* string_buffer, const char* basic_type_name, const char* method_name);
 };
 
 SPVM_ENV* SPVM_NATIVE_new_env_raw();
@@ -493,7 +493,6 @@ enum {
 
 enum {
   SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_UNKNOWN,
-  SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NOT_FOUND_CLASS,
   SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_UNDEF,
   SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_VOID,
   SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC,
