@@ -10,9 +10,8 @@ struct spvm_runtime_basic_type {
   int32_t id;
   int32_t category;
   int32_t name_id;
-  int32_t class_name_id;
-  int32_t class_rel_file_id;
-  int32_t class_path_id;
+  int32_t dir_id;
+  int32_t rel_file_id;
   int32_t init_method_id;
   int32_t destructor_method_id;
   int32_t required_method_id;
@@ -26,12 +25,11 @@ struct spvm_runtime_basic_type {
   int32_t class_vars_base_id;
   int32_t class_vars_length;
   int32_t fields_size;
-  int32_t parent_class_basic_type_id;
+  int32_t parent_id;
   int32_t version_string_id;
   int8_t has_init_block;
   int8_t is_anon;
   int8_t is_pointer;
-  int8_t is_class;
 };
 
 #endif
