@@ -9,7 +9,7 @@
 struct spvm_runtime_class_var {
   int32_t id;
   int32_t name_id;
-  int32_t class_basic_type_id;
+  int32_t current_basic_type_id;
   int32_t basic_type_id;
   int32_t type_dimension;
   int32_t type_flag;
