@@ -15,7 +15,7 @@ struct spvm_runtime_method {
   int32_t opcodes_length;
   int32_t id;
   int32_t name_id;
-  int32_t class_basic_type_id;
+  int32_t current_basic_type_id;
   int32_t call_stack_byte_vars_length;
   int32_t call_stack_short_vars_length;
   int32_t call_stack_int_vars_length;
@@ -28,7 +28,7 @@ struct spvm_runtime_method {
   int32_t return_basic_type_id;
   int32_t return_type_dimension;
   int32_t return_type_flag;
-  int8_t is_class_method;
+  int8_t is_static;
   int8_t is_init;
   int8_t is_anon;
   int8_t is_precompile;
