@@ -60,7 +60,7 @@ SPVM_COMPILER* SPVM_COMPILER_new() {
   compiler->constant_strings_buffer = SPVM_STRING_BUFFER_new(compiler->allocator, 8192, SPVM_ALLOCATOR_C_ALLOC_TYPE_PERMANENT);
   
   // Eternal information
-  compiler->class_paths = SPVM_LIST_new_list_permanent(compiler->allocator, 0);
+  compiler->include_dirs = SPVM_LIST_new_list_permanent(compiler->allocator, 0);
   compiler->basic_types = SPVM_LIST_new_list_permanent(compiler->allocator, 0);
   compiler->basic_type_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
   compiler->methods = SPVM_LIST_new_list_permanent(compiler->allocator, 0);
@@ -71,53 +71,65 @@ SPVM_COMPILER* SPVM_COMPILER_new() {
   compiler->opcode_array = SPVM_OPCODE_ARRAY_new(compiler);
   compiler->source_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
   compiler->switch_infos = SPVM_LIST_new_list_permanent(compiler->allocator, 0);
-  compiler->not_found_class_name_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
+  compiler->if_require_not_found_basic_type_name_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
   
   return compiler;
 }
 
-void SPVM_COMPILER_add_source(SPVM_COMPILER* compiler, const char* class_name, const char* source, int32_t length) {
+void SPVM_COMPILER_add_source(SPVM_COMPILER* compiler, const char* basic_type_name, const char* source, int32_t length) {
   SPVM_STRING_BUFFER* source_buffer = SPVM_STRING_BUFFER_new(compiler->allocator, length, SPVM_ALLOCATOR_C_ALLOC_TYPE_PERMANENT);
   SPVM_STRING_BUFFER_add_len(source_buffer, (char*)source, strlen(source));
-  SPVM_HASH_set(compiler->source_symtable, class_name, strlen(class_name), (void*)source_buffer);
+  SPVM_HASH_set(compiler->source_symtable, basic_type_name, strlen(basic_type_name), (void*)source_buffer);
 }
 
-void SPVM_COMPILER_add_basic_type(SPVM_COMPILER* compiler, int32_t basic_type_id, int32_t basic_type_category) {
-   SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
-   basic_type->id = basic_type_id;
+void SPVM_COMPILER_add_basic_type_core(SPVM_COMPILER* compiler, int32_t basic_type_id, int32_t basic_type_category) {
+   const char* basic_type_name = SPVM_BASIC_TYPE_get_basic_type_name(compiler, basic_type_id);
+   SPVM_BASIC_TYPE* basic_type = SPVM_COMPILER_add_basic_type(compiler, basic_type_name);
+   assert(basic_type->id == basic_type_id);
    basic_type->category = basic_type_category;
-   const char* basic_type_name_tmp = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
-   SPVM_CONSTANT_STRING* basic_type_name_string = SPVM_CONSTANT_STRING_new(compiler, basic_type_name_tmp, strlen(basic_type_name_tmp));
-   basic_type->name = basic_type_name_string->value;
-   SPVM_LIST_push(compiler->basic_types, basic_type);
-   SPVM_HASH_set(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
+}
+
+SPVM_BASIC_TYPE* SPVM_COMPILER_add_basic_type(SPVM_COMPILER* compiler, const char* basic_type_name) {
+  
+   SPVM_BASIC_TYPE* basic_type = SPVM_HASH_get(compiler->basic_type_symtable, basic_type_name, strlen(basic_type_name));
+   
+   if (!basic_type) {
+     basic_type = SPVM_BASIC_TYPE_new(compiler);
+     basic_type->id = compiler->basic_types->length;
+     SPVM_CONSTANT_STRING* basic_type_name_string = SPVM_CONSTANT_STRING_new(compiler, basic_type_name, strlen(basic_type_name));
+     basic_type->name = basic_type_name_string->value;
+     SPVM_LIST_push(compiler->basic_types, basic_type);
+     SPVM_HASH_set(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
+  }
+  
+   return basic_type;
 }
 
 void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   // Add basic_types
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_UNKNOWN, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_UNKNOWN);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_UNDEF, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_UNDEF);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_VOID, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_VOID);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_INT, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_LONG, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_STRING, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_STRING);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ANY_OBJECT, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_ANY_OBJECT);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_INT_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_LONG_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_BOOL_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_COMMAND_INFO_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
-  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ADDRESS_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_UNKNOWN, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_UNKNOWN);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_UNDEF, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_UNDEF);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_VOID, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_VOID);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_INT, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_LONG, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_NUMERIC);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_STRING, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_STRING);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ANY_OBJECT, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_ANY_OBJECT);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_BYTE_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_SHORT_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_INT_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_LONG_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_FLOAT_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_BOOL_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_COMMAND_INFO_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
+  SPVM_COMPILER_add_basic_type_core(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ADDRESS_CLASS, SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_CLASS);
 }
 
 int32_t SPVM_COMPILER_get_error_messages_length(SPVM_COMPILER* compiler) {
@@ -140,13 +152,13 @@ void SPVM_COMPILER_print_error_messages(SPVM_COMPILER* compiler, FILE* fh) {
   }
 }
 
-void SPVM_COMPILER_use(SPVM_COMPILER* compiler, const char* class_name, const char* file, int32_t line) {
-  SPVM_OP* op_name_class = SPVM_OP_new_op_name(compiler, class_name, file, line);
+void SPVM_COMPILER_use(SPVM_COMPILER* compiler, const char* basic_type_name, const char* file, int32_t line) {
+  SPVM_OP* op_name_class = SPVM_OP_new_op_name(compiler, basic_type_name, file, line);
   SPVM_OP* op_type_class = SPVM_OP_build_basic_type(compiler, op_name_class);
   SPVM_OP* op_use = SPVM_OP_new_op_use(compiler, op_name_class->file, op_name_class->line);
-  SPVM_OP* op_name_class_alias = NULL;
+  SPVM_OP* op_name_alias = NULL;
   int32_t is_require = 0;
-  SPVM_OP_build_use(compiler, op_use, op_type_class, op_name_class_alias, is_require);
+  SPVM_OP_build_use(compiler, op_use, op_type_class, op_name_alias, is_require);
   SPVM_LIST_push(compiler->op_use_stack, op_use);
 }
 
@@ -175,7 +187,7 @@ int32_t SPVM_COMPILER_use_default_loaded_classes(SPVM_COMPILER* compiler) {
   SPVM_COMPILER_use(compiler, "Address", "Address", 0);
 }
 
-int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
+int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* basic_type_name) {
   
   compiler->cur_basic_type_base = compiler->basic_types->length;
   
@@ -185,86 +197,86 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
     
     // Add Bool source
     {
-      const char* class_name = "Bool";
+      const char* basic_type_name = "Bool";
       const char* source = "class Bool {\n  INIT {\n    $TRUE = new Bool;\n    $TRUE->{value} = 1;\n    $FALSE = new Bool;\n    $FALSE->{value} = 0;\n  }\n  \n  our $TRUE : ro Bool;\n  our $FALSE : ro Bool;\n  has value : ro int;\n}";
-      SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
     }
     
     // Add Error source
     {
-      const char* class_name = "Error";
+      const char* basic_type_name = "Error";
       const char* source = "class Error;";
-      SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
     }
     
     // Add Error::System source
     {
-      const char* class_name = "Error::System";
+      const char* basic_type_name = "Error::System";
       const char* source = "class Error::System extends Error;";
-      SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
     }
     
     // Add Error::NotSupported source
     {
-      const char* class_name = "Error::NotSupported";
+      const char* basic_type_name = "Error::NotSupported";
       const char* source = "class Error::NotSupported extends Error;";
-      SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
     }
     
     // Add Byte source
     {
-      const char* class_name = "Byte";
+      const char* basic_type_name = "Byte";
       const char* source = "class Byte {\n  has value : ro byte;\n  static method new : Byte ($value : int) {\n    my $self = new Byte;\n    $self->{value} = (byte)$value;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
     }
     
     // Add Short source
     {
-      const char* class_name = "Short";
+      const char* basic_type_name = "Short";
       const char* source = "class Short {\n  has value : ro short;\n  static method new : Short ($value : int) {\n    my $self = new Short;\n    $self->{value} = (short)$value;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
     }
     
     // Add Int source
     {
-      const char* class_name = "Int";
+      const char* basic_type_name = "Int";
       const char* source = "class Int {\n  has value : ro int;\n  static method new : Int ($value : int) {\n    my $self = new Int;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
     }
     
     // Add Long source
     {
-      const char* class_name = "Long";
+      const char* basic_type_name = "Long";
       const char* source = "class Long {\n  has value : ro long;\n  static method new : Long ($value : long) {\n    my $self = new Long;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
     }
     
     // Add Float source
     {
-      const char* class_name = "Float";
+      const char* basic_type_name = "Float";
       const char* source = "class Float {\n  has value : ro float;\n  static method new : Float ($value : float) {\n    my $self = new Float;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
     }
     
     // Add Double source
     {
-      const char* class_name = "Double";
+      const char* basic_type_name = "Double";
       const char* source = "class Double {\n  has value : ro double;\n  static method new : Double ($value : double) {\n    my $self = new Double;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
     }
     
     // Add CommandInfo source
     {
-      const char* class_name = "CommandInfo";
+      const char* basic_type_name = "CommandInfo";
       const char* source = "class CommandInfo {\n  our $PROGRAM_NAME : ro string;\n  our $ARGV : ro string[];\n  our $BASE_TIME : ro long;\n  }";
-      SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
     }
     
     // Add Address source
     {
-      const char* class_name = "Address";
+      const char* basic_type_name = "Address";
       const char* source = "class Address : pointer {\n  static method new : Address () {\n    my $self = new Address;\n    return $self;\n  }\n}";
-      SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+      SPVM_COMPILER_add_source(compiler, basic_type_name, source, strlen(source));
     }
   }
   
@@ -291,22 +303,22 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
   compiler->ops = SPVM_LIST_new(compiler->allocator, 0, SPVM_ALLOCATOR_C_ALLOC_TYPE_TMP);
   compiler->op_use_stack = SPVM_LIST_new(compiler->allocator, 0, SPVM_ALLOCATOR_C_ALLOC_TYPE_TMP);
   compiler->op_types = SPVM_LIST_new(compiler->allocator, 0, SPVM_ALLOCATOR_C_ALLOC_TYPE_TMP);
-  compiler->used_class_name_symtable = SPVM_HASH_new(compiler->allocator, 0, SPVM_ALLOCATOR_C_ALLOC_TYPE_TMP);
+  compiler->used_basic_type_name_symtable = SPVM_HASH_new(compiler->allocator, 0, SPVM_ALLOCATOR_C_ALLOC_TYPE_TMP);
   for (int32_t basic_type_index = 0; basic_type_index < compiler->basic_types->length; basic_type_index++) {
-    SPVM_BASIC_TYPE* class_basic_type = SPVM_LIST_get(compiler->basic_types, basic_type_index);
-    if (!class_basic_type->is_class) { continue; }
+    SPVM_BASIC_TYPE* basic_type = SPVM_LIST_get(compiler->basic_types, basic_type_index);
+    if (!basic_type->is_class) { continue; }
     
-    const char* class_name = class_basic_type->name;
-    SPVM_HASH_set(compiler->used_class_name_symtable, class_name, strlen(class_name), (void*)class_name);
+    const char* basic_type_name = basic_type->name;
+    SPVM_HASH_set(compiler->used_basic_type_name_symtable, basic_type_name, strlen(basic_type_name), (void*)basic_type_name);
   }
   
   SPVM_COMPILER_use_default_loaded_classes(compiler);
    
   // Use the class that is specified at the argument
-  if (class_name) {
-    SPVM_CONSTANT_STRING* class_name_string = SPVM_CONSTANT_STRING_new(compiler, class_name, strlen(class_name));
-    class_name = class_name_string->value;
-    SPVM_COMPILER_use(compiler, class_name, start_file, start_line);
+  if (basic_type_name) {
+    SPVM_CONSTANT_STRING* basic_type_name_string = SPVM_CONSTANT_STRING_new(compiler, basic_type_name, strlen(basic_type_name));
+    basic_type_name = basic_type_name_string->value;
+    SPVM_COMPILER_use(compiler, basic_type_name, start_file, start_line);
   }
   
   /* Tokenize and Parse */
@@ -351,7 +363,7 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
       }
       case SPVM_OP_C_ID_USE: {
         SPVM_USE* use = op->uv.use;
-        use->class_alias_name = NULL;
+        use->alias_name = NULL;
         SPVM_ALLOCATOR_free_memory_block_tmp(compiler->allocator, use);
         break;
       }
@@ -424,12 +436,11 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
   
   // Clear unused pointers
   for (int32_t basic_type_index = compiler->cur_basic_type_base; basic_type_index < compiler->basic_types->length; basic_type_index++) {
-    SPVM_BASIC_TYPE* class_basic_type = SPVM_LIST_get(compiler->basic_types, basic_type_index);
-    if (!class_basic_type->is_class) { continue; }
+    SPVM_BASIC_TYPE* basic_type = SPVM_LIST_get(compiler->basic_types, basic_type_index);
     
-    SPVM_LIST_free(class_basic_type->allows);
+    SPVM_LIST_free(basic_type->allows);
     
-    SPVM_LIST* methods = class_basic_type->methods;
+    SPVM_LIST* methods = basic_type->methods;
     {
       int32_t method_index;
       for (method_index = 0; method_index < methods->length; method_index++) {
@@ -448,8 +459,8 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
   SPVM_LIST_free(compiler->op_types);
   compiler->op_types = NULL;
   
-  SPVM_HASH_free(compiler->used_class_name_symtable);
-  compiler->used_class_name_symtable = NULL;
+  SPVM_HASH_free(compiler->used_basic_type_name_symtable);
+  compiler->used_basic_type_name_symtable = NULL;
   
   SPVM_LIST_free(compiler->ops);
   compiler->ops = NULL;
@@ -633,29 +644,26 @@ int32_t* SPVM_COMPILER_create_runtime_codes(SPVM_COMPILER* compiler, SPVM_ALLOCA
     runtime_basic_type->name_id = basic_type_string->id;
     
     if (basic_type->is_class) {
-      SPVM_BASIC_TYPE* class_basic_type = SPVM_HASH_get(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name));
       
-      runtime_basic_type->is_class = 1;
+      SPVM_CONSTANT_STRING* class_class_rel_file_string = SPVM_HASH_get(compiler->constant_string_symtable, basic_type->rel_file, strlen(basic_type->rel_file));
+      runtime_basic_type->rel_file_id = class_class_rel_file_string->id;
       
-      SPVM_CONSTANT_STRING* class_class_rel_file_string = SPVM_HASH_get(compiler->constant_string_symtable, basic_type->class_rel_file, strlen(basic_type->class_rel_file));
-      runtime_basic_type->class_rel_file_id = class_class_rel_file_string->id;
-      
-      if (basic_type->class_path) {
-        SPVM_CONSTANT_STRING* class_class_path_string = SPVM_HASH_get(compiler->constant_string_symtable, basic_type->class_path, strlen(basic_type->class_path));
-        runtime_basic_type->class_path_id = class_class_path_string->id;
+      if (basic_type->dir) {
+        SPVM_CONSTANT_STRING* class_include_dir_string = SPVM_HASH_get(compiler->constant_string_symtable, basic_type->dir, strlen(basic_type->dir));
+        runtime_basic_type->dir_id = class_include_dir_string->id;
       }
       else {
-        runtime_basic_type->class_path_id = -1;
+        runtime_basic_type->dir_id = -1;
       }
       runtime_basic_type->has_init_block = basic_type->has_init_block;
       runtime_basic_type->is_anon = basic_type->is_anon;
-      runtime_basic_type->is_pointer = class_basic_type->is_pointer;
-      if (basic_type->parent_class_name) {
-        SPVM_BASIC_TYPE* parent_class_basic_type = SPVM_HASH_get(compiler->basic_type_symtable, basic_type->parent_class_name, strlen(basic_type->parent_class_name));
-        runtime_basic_type->parent_class_basic_type_id = parent_class_basic_type->id;
+      runtime_basic_type->is_pointer = basic_type->is_pointer;
+      if (basic_type->parent_name) {
+        SPVM_BASIC_TYPE* parent_basic_type = SPVM_HASH_get(compiler->basic_type_symtable, basic_type->parent_name, strlen(basic_type->parent_name));
+        runtime_basic_type->parent_id = parent_basic_type->id;
       }
       else {
-        runtime_basic_type->parent_class_basic_type_id = -1;
+        runtime_basic_type->parent_id = -1;
       }
       
       runtime_basic_type->fields_size = basic_type->fields_size;
@@ -755,7 +763,7 @@ int32_t* SPVM_COMPILER_create_runtime_codes(SPVM_COMPILER* compiler, SPVM_ALLOCA
     runtime_class_var->basic_type_id = class_var->type->basic_type->id;
     runtime_class_var->type_dimension = class_var->type->dimension;
     runtime_class_var->type_flag = class_var->type->flag;
-    runtime_class_var->class_basic_type_id = class_var->class_basic_type->id;
+    runtime_class_var->current_basic_type_id = class_var->current_basic_type->id;
     
     SPVM_CONSTANT_STRING* class_var_name_string = SPVM_HASH_get(compiler->constant_string_symtable, class_var->name, strlen(class_var->name));
     runtime_class_var->name_id = class_var_name_string->id;
@@ -785,7 +793,7 @@ int32_t* SPVM_COMPILER_create_runtime_codes(SPVM_COMPILER* compiler, SPVM_ALLOCA
     runtime_field->basic_type_id = field->type->basic_type->id;
     runtime_field->type_dimension = field->type->dimension;
     runtime_field->type_flag = field->type->flag;
-    runtime_field->class_basic_type_id = field->class_basic_type->id;
+    runtime_field->current_basic_type_id = field->current_basic_type->id;
     
     SPVM_CONSTANT_STRING* field_name_string = SPVM_HASH_get(compiler->constant_string_symtable, field->name, strlen(field->name));
     runtime_field->name_id = field_name_string->id;
@@ -825,8 +833,8 @@ int32_t* SPVM_COMPILER_create_runtime_codes(SPVM_COMPILER* compiler, SPVM_ALLOCA
     runtime_method->opcodes_base_id = method->opcodes_base_id;
     runtime_method->opcodes_length = method->opcodes_length;
     runtime_method->id = method->id;
-    runtime_method->class_basic_type_id = method->class_basic_type->id;
-    runtime_method->is_class_method = method->is_class_method;
+    runtime_method->current_basic_type_id = method->current_basic_type->id;
+    runtime_method->is_static = method->is_static;
     runtime_method->is_init = method->is_init;
     runtime_method->is_anon = method->is_anon;
     runtime_method->call_stack_byte_vars_length  = method->call_stack_byte_vars_length;
@@ -955,7 +963,7 @@ void SPVM_COMPILER_free(SPVM_COMPILER* compiler) {
     SPVM_ALLOCATOR_free_memory_block_tmp(compiler->allocator, (void*)start_file);
   }
   
-  SPVM_COMPILER_clear_class_paths(compiler);
+  SPVM_COMPILER_clear_include_dirs(compiler);
   
   // Free allocator
   SPVM_ALLOCATOR_free(compiler->allocator);
@@ -991,32 +999,32 @@ void SPVM_COMPILER_set_start_line(SPVM_COMPILER* compiler, int32_t start_line) {
   compiler->start_line = start_line;
 }
 
-int32_t SPVM_COMPILER_get_class_paths_length(SPVM_COMPILER* compiler) {
-  SPVM_LIST* class_paths = compiler->class_paths;
-  int32_t class_paths_length = class_paths->length;
-  return class_paths_length;
+int32_t SPVM_COMPILER_get_include_dirs_length(SPVM_COMPILER* compiler) {
+  SPVM_LIST* include_dirs = compiler->include_dirs;
+  int32_t include_dirs_length = include_dirs->length;
+  return include_dirs_length;
 }
 
-void SPVM_COMPILER_add_class_path(SPVM_COMPILER* compiler, const char* class_path) {  
-  int32_t class_path_length = strlen(class_path);
-  char* compiler_class_path = SPVM_ALLOCATOR_alloc_memory_block_tmp(compiler->allocator, class_path_length + 1);
-  memcpy(compiler_class_path, class_path, class_path_length);
-  SPVM_LIST_push(compiler->class_paths, (void*)compiler_class_path);
+void SPVM_COMPILER_add_include_dir(SPVM_COMPILER* compiler, const char* include_dir) {  
+  int32_t include_dir_length = strlen(include_dir);
+  char* compiler_include_dir = SPVM_ALLOCATOR_alloc_memory_block_tmp(compiler->allocator, include_dir_length + 1);
+  memcpy(compiler_include_dir, include_dir, include_dir_length);
+  SPVM_LIST_push(compiler->include_dirs, (void*)compiler_include_dir);
 }
 
-void SPVM_COMPILER_clear_class_paths(SPVM_COMPILER* compiler) {
-  int32_t class_paths_length = SPVM_COMPILER_get_class_paths_length(compiler);
+void SPVM_COMPILER_clear_include_dirs(SPVM_COMPILER* compiler) {
+  int32_t include_dirs_length = SPVM_COMPILER_get_include_dirs_length(compiler);
   
-  for (int32_t i = 0; i < class_paths_length; i++) {
-    const char* class_path = SPVM_COMPILER_get_class_path(compiler, i);
-    SPVM_ALLOCATOR_free_memory_block_tmp(compiler->allocator, (void*)class_path);
-    class_path = NULL;
+  for (int32_t i = 0; i < include_dirs_length; i++) {
+    const char* include_dir = SPVM_COMPILER_get_include_dir(compiler, i);
+    SPVM_ALLOCATOR_free_memory_block_tmp(compiler->allocator, (void*)include_dir);
+    include_dir = NULL;
   }
   
-  SPVM_LIST_clear(compiler->class_paths);
+  SPVM_LIST_clear(compiler->include_dirs);
 }
 
-const char* SPVM_COMPILER_get_class_path (SPVM_COMPILER* compiler, int32_t class_path_id) {
-  const char* class_path = SPVM_LIST_get(compiler->class_paths, class_path_id);
-  return class_path;
+const char* SPVM_COMPILER_get_include_dir (SPVM_COMPILER* compiler, int32_t include_dir_id) {
+  const char* include_dir = SPVM_LIST_get(compiler->include_dirs, include_dir_id);
+  return include_dir;
 }
