@@ -1,3 +1,6 @@
+// Copyright (c) 2023 Yuki Kimoto
+// MIT License
+
 #include <string.h>
 #include <stdlib.h>
 #include <assert.h>
@@ -166,6 +169,13 @@ void* SPVM_LIST_pop(SPVM_LIST* list) {
   }
 }
 
+void SPVM_LIST_clear(SPVM_LIST* list) {
+  
+  while (list->length > 0) {
+    list->length--;
+  }
+}
+
 void* SPVM_LIST_shift(SPVM_LIST* list) {
   
   assert(list->length >= 0);
