@@ -54,9 +54,9 @@ int32_t SPVM_VM_call_method(SPVM_ENV* env, SPVM_VALUE* stack, int32_t current_me
   const char* current_method_name =  SPVM_API_RUNTIME_get_name(runtime, current_method->name_id);
   
   // Runtime class
-  SPVM_RUNTIME_BASIC_TYPE* current_class_basic_type = SPVM_API_RUNTIME_get_basic_type(runtime, current_method->class_basic_type_id);
+  SPVM_RUNTIME_BASIC_TYPE* current_basic_type = SPVM_API_RUNTIME_get_basic_type(runtime, current_method->current_basic_type_id);
 
-  const char* current_class_name =  SPVM_API_RUNTIME_get_name(runtime, current_class_basic_type->name_id);
+  const char* current_class_name =  SPVM_API_RUNTIME_get_name(runtime, current_basic_type->name_id);
 
   // Operation codes
   SPVM_OPCODE* opcodes = runtime->opcodes;
@@ -1166,20 +1166,20 @@ int32_t SPVM_VM_call_method(SPVM_ENV* env, SPVM_VALUE* stack, int32_t current_me
         void* string = object_vars[opcode->operand0];
         int32_t line = opcode->operand1;
         
-        const char* class_path = NULL;
-        const char* class_path_sep;
-        int32_t class_path_id = current_class_basic_type->class_path_id;
-        if (class_path_id >= 0) {
-          class_path_sep = "/";
-          class_path = SPVM_API_RUNTIME_get_constant_string_value(runtime, current_class_basic_type->class_path_id, NULL);
+        const char* include_dir = NULL;
+        const char* include_dir_sep;
+        int32_t include_dir_id = current_basic_type->dir_id;
+        if (include_dir_id >= 0) {
+          include_dir_sep = "/";
+          include_dir = SPVM_API_RUNTIME_get_constant_string_value(runtime, current_basic_type->dir_id, NULL);
         }
         else {
-          class_path_sep = "";
-          class_path = "";
+          include_dir_sep = "";
+          include_dir = "";
         }
-        const char* class_rel_file = SPVM_API_RUNTIME_get_constant_string_value(runtime, current_class_basic_type->class_rel_file_id, NULL);
+        const char* class_rel_file = SPVM_API_RUNTIME_get_constant_string_value(runtime, current_basic_type->rel_file_id, NULL);
 
-        SPVM_IMPLEMENT_WARN(env, stack, string, class_path, class_path_sep, class_rel_file, line);
+        SPVM_IMPLEMENT_WARN(env, stack, string, include_dir, include_dir_sep, class_rel_file, line);
         
         break;
       }
@@ -2152,8 +2152,8 @@ int32_t SPVM_VM_call_method(SPVM_ENV* env, SPVM_VALUE* stack, int32_t current_me
         SPVM_RUNTIME_METHOD* method = SPVM_API_RUNTIME_get_method(runtime, method_id);
         const char* method_name = SPVM_API_RUNTIME_get_constant_string_value(runtime, method->name_id, NULL);
         
-        SPVM_RUNTIME_BASIC_TYPE* method_class_basic_type = SPVM_API_RUNTIME_get_basic_type(runtime, method->class_basic_type_id);
-        const char* class_name = SPVM_API_RUNTIME_get_constant_string_value(runtime, method_class_basic_type->name_id, NULL);
+        SPVM_RUNTIME_BASIC_TYPE* method_current_basic_type = SPVM_API_RUNTIME_get_basic_type(runtime, method->current_basic_type_id);
+        const char* class_name = SPVM_API_RUNTIME_get_constant_string_value(runtime, method_current_basic_type->name_id, NULL);
         
         void* object = stack[0].oval;
         SPVM_IMPLEMENT_CALL_INSTANCE_METHOD(env, stack, object, class_name, method_name, args_stack_length, &error_id, tmp_buffer, sizeof(tmp_buffer));
