@@ -20,33 +20,33 @@ The instance of the L<Runtime|SPVM::Runtime> class is build by the L</"build_run
   
   my $compiler = Compiler->new;
   
-  $compiler->add_class_path("lib");
+  $compiler->add_include_dir("lib");
   
   $compiler->set_start_file(__FILE__);
   
   {
-    my $class_name = "Foo";
+    my $basic_type_name = "Foo";
     $compiler->set_start_line(__LINE__ + 1);
-    my $success = $compiler->compile($class_name);
+    my $success = $compiler->compile($basic_type_name);
     unless ($success) {
       my $error_messages = $compiler->get_error_messages;
       for my $error_message (@$error_messages) {
         warn "$error_message";
       }
-      die "Can't compile the \"$class_name\" class";
+      die "Can't compile the \"$basic_type_name\" class";
     }
   }
   
   {
-    my $class_name = "Bar";
+    my $basic_type_name = "Bar";
     $compiler->set_start_line(__LINE__ + 1);
-    my $success = $compiler->compile($class_name);
+    my $success = $compiler->compile($basic_type_name);
     unless ($success) {
       my $error_messages = $compiler->get_error_messages;
       for my $error_message (@$error_messages) {
         warn "$error_message";
       }
-      die "Can't compile the \"$class_name\" class";
+      die "Can't compile the \"$basic_type_name\" class";
     }
   }
   
@@ -68,9 +68,9 @@ Creates a new C<Compiler> object and returns it.
 
 =head1 Instance Methods
 
-=head2 add_class_path
+=head2 add_include_dir
 
-  native method add_class_path : void ($class_path : string);
+  native method add_include_dir : void ($include_dir : string);
 
 Adds a class directory to search for classes.
 
@@ -88,7 +88,7 @@ Sets the line to start compiling by the L</"compile"> method.
 
 =head2 compile
 
-  native method compile : int ($class_name : string);
+  native method compile : int ($basic_type_name : string);
 
 Compiles the specified class and the classes that are load in the specified class. 
 
