@@ -67,7 +67,7 @@ Runtime native APIs have its IDs.
   43 get_method_name_id
   44 reserved44
   45 reserved45
-  46 get_method_is_class_method
+  46 get_method_is_static
   47 get_method_is_anon
   48 get_method_is_native
   49 get_method_is_precompile
@@ -106,10 +106,10 @@ Runtime native APIs have its IDs.
   82 reserved82
   83 is_object_type
   84 reserved84
-  85 class_init_flags
+  85 init_flags
   86 can_assign
-  87 get_basic_type_class_rel_file_id
-  88 get_basic_type_class_path_id
+  87 get_basic_type_rel_file_id
+  88 get_basic_type_dir_id
   89 get_basic_type_is_anon
   90 get_basic_type_fields_base_id
   91 get_basic_type_fields_length
@@ -119,7 +119,7 @@ Runtime native APIs have its IDs.
   95 get_basic_type_class_vars_length
   96 get_basic_type_anon_methods_base_id
   97 get_basic_type_anon_methods_length
-  98 get_basic_type_is_class
+  98 reserved98
   99 get_basic_types_length
   100 get_field_basic_type_id
   101 get_field_type_dimension
@@ -133,7 +133,7 @@ Runtime native APIs have its IDs.
   106 get_arg_basic_type_id
   107 get_arg_type_dimension
   108 get_arg_type_flag
-  109 get_method_class_basic_type_id
+  109 get_method_current_basic_type_id
   110 get_basic_type_parent_class_basic_type_id
 
 =head1 Runtime Native APIs
@@ -186,17 +186,17 @@ Runtime native APIs have its IDs.
 
   int32_t (*get_basic_type_category)(void* runtime, int32_t basic_type_id);
 
-=head2 get_class_name_id
+=head2 get_basic_type_name_id
 
-  int32_t (*get_class_name_id)(void* runtime, int32_t class_id);
+  int32_t (*get_basic_type_name_id)(void* runtime, int32_t class_id);
 
 =head2 get_class_class_rel_file_id
 
   int32_t (*get_class_class_rel_file_id)(void* runtime, int32_t class_id);
 
-=head2 get_class_class_path_id
+=head2 get_class_include_dir_id
 
-  int32_t (*get_class_class_path_id)(void* runtime, int32_t class_id);
+  int32_t (*get_class_include_dir_id)(void* runtime, int32_t class_id);
 
 =head2 get_class_is_anon
 
@@ -240,7 +240,7 @@ Runtime native APIs have its IDs.
 
 =head2 get_class_var_id_by_name
 
-  int32_t (*get_class_var_id_by_name)(void* runtime, const char* class_name, const char* class_var_name);
+  int32_t (*get_class_var_id_by_name)(void* runtime, const char* basic_type_name, const char* class_var_name);
 
 =head2 get_class_var_name_id
 
@@ -252,7 +252,7 @@ Runtime native APIs have its IDs.
 
 =head2 get_field_id_by_name
 
-  int32_t (*get_field_id_by_name)(void* runtime, const char* class_name, const char* field_name);
+  int32_t (*get_field_id_by_name)(void* runtime, const char* basic_type_name, const char* field_name);
 
 =head2 get_field_name_id
 
@@ -264,15 +264,15 @@ Runtime native APIs have its IDs.
 
 =head2 get_method_id_by_name
 
-  int32_t (*get_method_id_by_name)(void* runtime, const char* class_name, const char* method_name);
+  int32_t (*get_method_id_by_name)(void* runtime, const char* basic_type_name, const char* method_name);
 
 =head2 get_method_name_id
 
   int32_t (*get_method_name_id)(void* runtime, int32_t method_id);
 
-=head2 get_method_is_class_method
+=head2 get_method_is_static
 
-  int32_t (*get_method_is_class_method)(void* runtime, int32_t method_id);
+  int32_t (*get_method_is_static)(void* runtime, int32_t method_id);
 
 =head2 get_method_is_anon
 
@@ -420,7 +420,7 @@ Runtime native APIs have its IDs.
 
 Gets the ID of the constant string of the version number.
 
-=head2 class_init_flags
+=head2 init_flags
 
 Internally used.
 
@@ -476,17 +476,17 @@ Internally used.
 
   int32_t (*get_arg_type_flag)(void* runtime, int32_t arg_id);
 
-=head2 get_method_class_basic_type_id
+=head2 get_method_current_basic_type_id
 
-  int32_t (*get_method_class_basic_type_id)(void* runtime, int32_t method_id);
+  int32_t (*get_method_current_basic_type_id)(void* runtime, int32_t method_id);
 
-=head2 get_field_class_basic_type_id
+=head2 get_field_current_basic_type_id
 
-  int32_t (*get_field_class_basic_type_id)(void* runtime, int32_t field_id);
+  int32_t (*get_field_current_basic_type_id)(void* runtime, int32_t field_id);
 
-=head2 get_class_var_class_basic_type_id
+=head2 get_class_var_current_basic_type_id
 
-  int32_t (*get_class_var_class_basic_type_id)(void* runtime, int32_t class_var_id);
+  int32_t (*get_class_var_current_basic_type_id)(void* runtime, int32_t class_var_id);
 
 =head2 get_basic_type_parent_class_basic_type_id
 
