@@ -650,14 +650,14 @@ int32_t SPVM__Fn__get_version_string(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_class_name = stack[0].oval;
   
   if (!obj_class_name) {
-    return env->die(env, stack, "The $class_name must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $basic_type_name must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   const char* class_name = env->get_chars(env, stack, obj_class_name);
   
   int32_t basic_type_id = env->api->runtime->get_basic_type_id_by_name(env->runtime, class_name);
   if (basic_type_id < 0) {
-    return env->die(env, stack, "The class specified by the $class_name must be loaded", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The class specified by the $basic_type_name must be loaded", __func__, FILE_NAME, __LINE__);
   }
   
   const char* version_string = env->get_version_string(env, stack, basic_type_id);
@@ -685,14 +685,14 @@ int32_t SPVM__Fn__get_version_number(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_class_name = stack[0].oval;
   
   if (!obj_class_name) {
-    return env->die(env, stack, "The $class_name must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $basic_type_name must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   const char* class_name = env->get_chars(env, stack, obj_class_name);
   
   int32_t basic_type_id = env->api->runtime->get_basic_type_id_by_name(env->runtime, class_name);
   if (basic_type_id < 0) {
-    return env->die(env, stack, "The class specified by the $class_name must be loaded", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The class specified by the $basic_type_name must be loaded", __func__, FILE_NAME, __LINE__);
   }
   
   double version_number = env->get_version_number(env, stack, basic_type_id);
