@@ -27,39 +27,39 @@ our $API;
 sub load_dynamic_libs {
   my ($runtime, $dynamic_lib_files) = @_;
 
-  my $class_names = $runtime->get_class_names->to_strings;
+  my $basic_type_names = $runtime->get_basic_type_names->to_strings;
 
   # Set addresses of native methods and precompile methods
-  for my $class_name (@$class_names) {
-    next if $class_name =~ /::anon/;
+  for my $basic_type_name (@$basic_type_names) {
+    next if $basic_type_name =~ /::anon/;
     
     for my $category ('precompile', 'native') {
-
+      
       my $get_method_names_options = $runtime->__api->new_options({
         $category => $runtime->__api->class('Int')->new(1)
       });
       
-      my $method_names = $runtime->get_method_names($class_name, $get_method_names_options)->to_strings;
+      my $method_names = $runtime->get_method_names($basic_type_name, $get_method_names_options)->to_strings;
       
       if (@$method_names) {
         # Build classs - Compile C source codes and link them to SPVM precompile method
         # Shared library which is already installed in distribution directory
-        my $class_file = $runtime->get_class_file($class_name)->to_string;
+        my $class_file = $runtime->get_file($basic_type_name)->to_string;
         my $dynamic_lib_file = SPVM::Builder::Util::get_dynamic_lib_file_dist($class_file, $category);
         
         # Try to build the shared library at runtime if shared library is not found
         unless (-f $dynamic_lib_file) {
-          my $class_file = $runtime->get_class_file($class_name)->to_string;
-          my $method_names = $runtime->get_method_names($class_name, $get_method_names_options)->to_strings;
-          my $anon_class_names = $runtime->get_anon_class_names($class_name)->to_strings;
-          my $dl_func_list = SPVM::Builder::Util::create_dl_func_list($class_name, $method_names, $anon_class_names, {category => $category});
-          my $precompile_source = $runtime->build_precompile_class_source($class_name)->to_string;
+          my $class_file = $runtime->get_file($basic_type_name)->to_string;
+          my $method_names = $runtime->get_method_names($basic_type_name, $get_method_names_options)->to_strings;
+          my $anon_class_names = $runtime->get_basic_type_anon_basic_type_names($basic_type_name)->to_strings;
+          my $dl_func_list = SPVM::Builder::Util::create_dl_func_list($basic_type_name, $method_names, $anon_class_names, {category => $category});
+          my $precompile_source = $runtime->build_precompile_source($basic_type_name)->to_string;
           
-          $dynamic_lib_file = $BUILDER->build_at_runtime($class_name, {class_file => $class_file, category => $category, dl_func_list => $dl_func_list, precompile_source => $precompile_source});
+          $dynamic_lib_file = $BUILDER->build_at_runtime($basic_type_name, {class_file => $class_file, category => $category, dl_func_list => $dl_func_list, precompile_source => $precompile_source});
         }
         
         if (-f $dynamic_lib_file) {
-          $dynamic_lib_files->{$category}{$class_name} = $dynamic_lib_file;
+          $dynamic_lib_files->{$category}{$basic_type_name} = $dynamic_lib_file;
         }
       }
     }
@@ -71,21 +71,22 @@ sub load_dynamic_libs {
       $category => $runtime->__api->class('Int')->new(1)
     });
     
-    for my $class_name (keys %{$dynamic_lib_files->{$category}}) {
-      next unless grep { "$_" eq $class_name } @$class_names;
+    for my $basic_type_name (keys %{$dynamic_lib_files->{$category}}) {
+      next unless grep { "$_" eq $basic_type_name } @$basic_type_names;
       
-      my $dynamic_lib_file = $dynamic_lib_files->{$category}{$class_name};
-      my $method_names = $runtime->get_method_names($class_name, $get_method_names_options)->to_strings;
-      my $anon_class_names = $runtime->get_anon_class_names($class_name)->to_strings;
-      my $method_addresses = SPVM::Builder::Util::get_method_addresses($dynamic_lib_file, $class_name, $method_names, $anon_class_names, $category);
+      my $dynamic_lib_file = $dynamic_lib_files->{$category}{$basic_type_name};
+      my $method_names = $runtime->get_method_names($basic_type_name, $get_method_names_options)->to_strings;
+      my $anon_class_names = $runtime->get_basic_type_anon_basic_type_names($basic_type_name)->to_strings;
+      
+      my $method_addresses = SPVM::Builder::Util::get_method_addresses($dynamic_lib_file, $basic_type_name, $method_names, $anon_class_names, $category);
       
       for my $method_name (sort keys %$method_addresses) {
         my $cfunc_address = $method_addresses->{$method_name};
         if ($category eq 'native') {
-          $runtime->set_native_method_address($class_name, $method_name, $runtime->__api->new_address_object($cfunc_address));
+          $runtime->set_native_method_address($basic_type_name, $method_name, $runtime->__api->new_address_object($cfunc_address));
         }
         elsif ($category eq 'precompile') {
-          $runtime->set_precompile_method_address($class_name, $method_name, $runtime->__api->new_address_object($cfunc_address));
+          $runtime->set_precompile_method_address($basic_type_name, $method_name, $runtime->__api->new_address_object($cfunc_address));
         }
       }
     }
@@ -100,7 +101,7 @@ sub init_runtime {
     }
     
     my $builder_compiler = SPVM::Builder::Compiler->new(
-      class_paths => $BUILDER->class_paths
+      include_dirs => $BUILDER->include_dirs
     );
     # Load SPVM Compilers
     $builder_compiler->use("Compiler", __FILE__, __LINE__);
@@ -129,8 +130,8 @@ sub init_runtime {
     $BUILDER_API = SPVM::ExchangeAPI->new(env => $BUILDER_ENV, stack => $BUILDER_STACK);
     
     $COMPILER = $BUILDER_API->class("Compiler")->new;
-    for my $class_path (@{$BUILDER->class_paths}) {
-      $COMPILER->add_class_path($class_path);
+    for my $include_dir (@{$BUILDER->include_dirs}) {
+      $COMPILER->add_include_dir($include_dir);
     }
     $RUNTIME = $COMPILER->build_runtime;
     
@@ -140,14 +141,14 @@ sub init_runtime {
 
 my $BIND_TO_PERL_CLASS_NAME_H = {};
 sub bind_to_perl {
-  my ($class_name) = @_;
+  my ($basic_type_name) = @_;
   
   my $perl_class_name_base = "SPVM::";
-  my $perl_class_name = "$perl_class_name_base$class_name";
+  my $perl_class_name = "$perl_class_name_base$basic_type_name";
   
   unless ($BIND_TO_PERL_CLASS_NAME_H->{$perl_class_name}) {
     
-    my $parent_class_name = $RUNTIME->get_parent_class_name($class_name);
+    my $parent_class_name = $RUNTIME->get_basic_type_parent_name($basic_type_name);
     my $parent_class_name_str = defined $parent_class_name ? "($parent_class_name)" : "()";
     
     # The inheritance
@@ -165,7 +166,7 @@ sub bind_to_perl {
       confess $error;
     }
     
-    my $method_names = $RUNTIME->get_method_names($class_name);
+    my $method_names = $RUNTIME->get_method_names($basic_type_name);
 
     for my $method_name (@$method_names) {
       
@@ -179,14 +180,14 @@ sub bind_to_perl {
       }
       
       my $perl_method_abs_name = "${perl_class_name}::$method_name";
-      my $is_class_method = $RUNTIME->get_method_is_class_method($class_name, $method_name);
+      my $is_static = $RUNTIME->get_method_is_static($basic_type_name, $method_name);
       
-      if ($is_class_method) {
+      if ($is_static) {
         # Define Perl method
         no strict 'refs';
         
         # Suppress refer to objects
-        my $class_name_string = "$class_name";
+        my $basic_type_name_string = "$basic_type_name";
         my $method_name_string = "$method_name";
         
         *{"$perl_method_abs_name"} = sub {
@@ -194,7 +195,7 @@ sub bind_to_perl {
           
           my $return_value;
           
-          eval { $return_value = SPVM::api()->call_method($class_name_string, $method_name_string, @_) };
+          eval { $return_value = SPVM::api()->call_method($basic_type_name_string, $method_name_string, @_) };
           my $error = $@;
           if ($error) {
             confess $error;
@@ -209,28 +210,23 @@ sub bind_to_perl {
 }
 
 
-sub build_class {
-  my ($class_name, $file, $line) = @_;
+sub build {
+  my ($basic_type_name, $file, $line) = @_;
   
   unless ($BUILDER) {
     my $build_dir = SPVM::Builder::Util::get_normalized_env('SPVM_BUILD_DIR');
     $BUILDER = SPVM::Builder->new(build_dir => $build_dir);
   }
   
-  my $start_classes_length = 0;
-  if ($RUNTIME) {
-    $start_classes_length = $RUNTIME->get_classes_length;
-  }
-  
   &init_runtime();
   
   # Add class informations
   my $build_success;
-  if (defined $class_name) {
+  if (defined $basic_type_name) {
     
     $COMPILER->set_start_file($file);
     $COMPILER->set_start_line($line);
-    my $success = $COMPILER->compile($class_name);
+    my $success = $COMPILER->compile($basic_type_name);
     unless ($success) {
       my $error_messages = $COMPILER->get_error_messages;
       for my $error_message (@$error_messages) {
