@@ -76,7 +76,7 @@ int32_t SPVM__Runtime__get_native_method_address(SPVM_ENV* env, SPVM_VALUE* stac
   return 0;
 }
 
-int32_t SPVM__Runtime__get_method_is_class_method(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Runtime__get_method_is_static(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e = 0;
 
@@ -95,9 +95,9 @@ int32_t SPVM__Runtime__get_method_is_class_method(SPVM_ENV* env, SPVM_VALUE* sta
   // Method id
   int32_t method_id = env->api->runtime->get_method_id_by_name(runtime, class_name, method_name);
   
-  int32_t is_class_method = env->api->runtime->get_method_is_class_method(runtime, method_id);
+  int32_t is_static = env->api->runtime->get_method_is_static(runtime, method_id);
   
-  stack[0].ival = is_class_method;
+  stack[0].ival = is_static;
   
   return 0;
 }
@@ -159,7 +159,7 @@ int32_t SPVM__Runtime__set_precompile_method_address(SPVM_ENV* env, SPVM_VALUE*
   return 0;
 }
 
-int32_t SPVM__Runtime__build_precompile_class_source(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Runtime__build_precompile_source(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e = 0;
   
@@ -180,13 +180,13 @@ int32_t SPVM__Runtime__build_precompile_class_source(SPVM_ENV* env, SPVM_VALUE*
   
   env->api->precompile->set_runtime(precompile, runtime);
   
-  env->api->precompile->build_class_source(precompile, string_buffer, class_name);
+  env->api->precompile->build_source(precompile, string_buffer, class_name);
   
   env->api->precompile->free_object(precompile);
 
   const char* string_buffer_value = env->api->string_buffer->get_value(string_buffer);
   int32_t string_buffer_length = env->api->string_buffer->get_length(string_buffer);
-  void* obj_precompile_class_source = env->new_string(env, stack, string_buffer_value, string_buffer_length);
+  void* obj_precompile_source = env->new_string(env, stack, string_buffer_value, string_buffer_length);
   
   // Free string buffer
   env->api->string_buffer->free_object(string_buffer);
@@ -194,7 +194,7 @@ int32_t SPVM__Runtime__build_precompile_class_source(SPVM_ENV* env, SPVM_VALUE*
   // Free allocator
   env->api->allocator->free_object(allocator);
 
-  stack[0].oval = obj_precompile_class_source;
+  stack[0].oval = obj_precompile_source;
   
   return 0;
 }
@@ -263,7 +263,7 @@ int32_t SPVM__Runtime__get_runtime_codes(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Runtime__get_classes_length(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Runtime__get_basic_type_names(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e = 0;
   
@@ -273,55 +273,21 @@ int32_t SPVM__Runtime__get_classes_length(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t basic_types_length = env->api->runtime->get_basic_types_length(runtime);
   
-  int32_t classes_length = 0;
+  void* obj_basic_type_names = env->new_string_array(env, stack, basic_types_length);
+  int32_t basic_type_index = 0;
   for (int32_t basic_type_id = 0; basic_type_id < basic_types_length; basic_type_id++) {
-    int32_t is_class = env->api->runtime->get_basic_type_is_class(runtime, basic_type_id);
-    if (is_class) {
-      classes_length++;
-    }
+    const char* basic_type_name = env->api->runtime->get_name(runtime, env->api->runtime->get_basic_type_name_id(runtime, basic_type_id));
+    void* obj_basic_type_name = env->new_string_nolen(env, stack, basic_type_name);
+    env->set_elem_object(env, stack, obj_basic_type_names, basic_type_index, obj_basic_type_name);
+    basic_type_index++;
   }
   
-  stack[0].ival = classes_length;
+  stack[0].oval = obj_basic_type_names;
   
   return 0;
 }
 
-int32_t SPVM__Runtime__get_class_names(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t e = 0;
-  
-  void* obj_self = stack[0].oval;
-  
-  void* runtime = env->get_pointer(env, stack, obj_self);
-  
-  int32_t basic_types_length = env->api->runtime->get_basic_types_length(runtime);
-  
-  int32_t classes_length = 0;
-  for (int32_t basic_type_id = 0; basic_type_id < basic_types_length; basic_type_id++) {
-    int32_t is_class = env->api->runtime->get_basic_type_is_class(runtime, basic_type_id);
-    if (is_class) {
-      classes_length++;
-    }
-  }
-  
-  void* obj_class_names = env->new_string_array(env, stack, classes_length);
-  int32_t class_index = 0;
-  for (int32_t basic_type_id = 0; basic_type_id < basic_types_length; basic_type_id++) {
-    int32_t is_class = env->api->runtime->get_basic_type_is_class(runtime, basic_type_id);
-    if (is_class) {
-      const char* basic_type_name = env->api->runtime->get_name(runtime, env->api->runtime->get_basic_type_name_id(runtime, basic_type_id));
-      void* obj_basic_type_name = env->new_string_nolen(env, stack, basic_type_name);
-      env->set_elem_object(env, stack, obj_class_names, class_index, obj_basic_type_name);
-      class_index++;
-    }
-  }
-  
-  stack[0].oval = obj_class_names;
-  
-  return 0;
-}
-
-int32_t SPVM__Runtime__get_class_file(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Runtime__get_file(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e = 0;
   
@@ -339,26 +305,26 @@ int32_t SPVM__Runtime__get_class_file(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   void* obj_class_file = NULL;
   if (class_basic_type_id >= 0) {
-    int32_t class_rel_file_id = env->api->runtime->get_basic_type_class_rel_file_id(runtime, class_basic_type_id);
-    int32_t class_path_id = env->api->runtime->get_basic_type_class_path_id(runtime, class_basic_type_id);
-    const char* class_path = NULL;
-    const char* class_path_sep;
-    if (class_path_id >= 0) {
-      class_path_sep = "/";
-      class_path = env->api->runtime->get_constant_string_value(runtime, class_path_id, NULL);
+    int32_t class_rel_file_id = env->api->runtime->get_basic_type_rel_file_id(runtime, class_basic_type_id);
+    int32_t include_dir_id = env->api->runtime->get_basic_type_dir_id(runtime, class_basic_type_id);
+    const char* include_dir = NULL;
+    const char* include_dir_sep;
+    if (include_dir_id >= 0) {
+      include_dir_sep = "/";
+      include_dir = env->api->runtime->get_constant_string_value(runtime, include_dir_id, NULL);
     }
     else {
-      class_path_sep = "";
-      class_path = "";
+      include_dir_sep = "";
+      include_dir = "";
     }
     const char* class_rel_file = env->api->runtime->get_constant_string_value(runtime, class_rel_file_id, NULL);
     
-    int32_t class_file_length = strlen(class_path) + strlen(class_path_sep) + strlen(class_rel_file);
+    int32_t class_file_length = strlen(include_dir) + strlen(include_dir_sep) + strlen(class_rel_file);
     obj_class_file = env->new_string(env, stack, NULL, class_file_length);
     char* class_file = (char*)env->get_chars(env, stack, obj_class_file);
-    memcpy(class_file, class_path, strlen(class_path));
-    memcpy(class_file + strlen(class_path), class_path_sep, strlen(class_path_sep));
-    memcpy(class_file + strlen(class_path) + strlen(class_path_sep), class_rel_file, strlen(class_rel_file));
+    memcpy(class_file, include_dir, strlen(include_dir));
+    memcpy(class_file + strlen(include_dir), include_dir_sep, strlen(include_dir_sep));
+    memcpy(class_file + strlen(include_dir) + strlen(include_dir_sep), class_rel_file, strlen(class_rel_file));
   }
   
   stack[0].oval = obj_class_file;
@@ -366,7 +332,7 @@ int32_t SPVM__Runtime__get_class_file(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Runtime__get_parent_class_name(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Runtime__get_basic_type_parent_name(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e = 0;
   
@@ -392,18 +358,18 @@ int32_t SPVM__Runtime__get_parent_class_name(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
-int32_t SPVM__Runtime__get_anon_class_names(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPVM__Runtime__get_basic_type_anon_basic_type_names(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t e = 0;
  
   void* obj_self = stack[0].oval;
   
-  void* obj_class_name = stack[1].oval;
-  const char* class_name = env->get_chars(env, stack, obj_class_name);
+  void* obj_basic_type = stack[1].oval;
+  const char* basic_type = env->get_chars(env, stack, obj_basic_type);
   
   void* runtime = env->get_pointer(env, stack, obj_self);
   
-  int32_t class_basic_type_id = env->api->runtime->get_basic_type_id_by_name(runtime, class_name);
+  int32_t class_basic_type_id = env->api->runtime->get_basic_type_id_by_name(runtime, basic_type);
   
   int32_t methods_length = env->api->runtime->get_basic_type_methods_length(runtime, class_basic_type_id);
   
@@ -416,21 +382,21 @@ int32_t SPVM__Runtime__get_anon_class_names(SPVM_ENV* env, SPVM_VALUE* stack) {
     }
   }
   
-  void* obj_anon_class_names = env->new_string_array(env, stack, anon_classes_length);
+  void* obj_anon_basic_type_names = env->new_string_array(env, stack, anon_classes_length);
   int32_t anon_class_index = 0;
   for (int32_t method_index = 0; method_index < methods_length; method_index++) {
     int32_t method_id = env->api->runtime->get_method_id_by_index(runtime, class_basic_type_id, method_index);
     int32_t is_anon_method = env->api->runtime->get_method_is_anon(runtime, method_id);
     if (is_anon_method) {
-      int32_t anon_class_basic_type_id = env->api->runtime->get_method_class_basic_type_id(runtime, method_id);
-      const char* anon_class_name = env->api->runtime->get_name(runtime, env->api->runtime->get_basic_type_name_id(runtime, anon_class_basic_type_id));
-      void* obj_anon_class_name = env->new_string_nolen(env, stack, anon_class_name);
-      env->set_elem_object(env, stack, obj_anon_class_names, anon_class_index, obj_anon_class_name);
+      int32_t anon_class_basic_type_id = env->api->runtime->get_method_current_basic_type_id(runtime, method_id);
+      const char* anon_basic_type = env->api->runtime->get_name(runtime, env->api->runtime->get_basic_type_name_id(runtime, anon_class_basic_type_id));
+      void* obj_anon_basic_type = env->new_string_nolen(env, stack, anon_basic_type);
+      env->set_elem_object(env, stack, obj_anon_basic_type_names, anon_class_index, obj_anon_basic_type);
       anon_class_index++;
     }
   }
   
-  stack[0].oval = obj_anon_class_names;
+  stack[0].oval = obj_anon_basic_type_names;
   
   return 0;
 }
